@@ -1,3 +1,10 @@
+/*
+ * Copyright (C) 1996-2014 The Squid Software Foundation and contributors
+ *
+ * Squid software is distributed under GPLv2+ license and includes
+ * contributions from numerous individuals and organizations.
+ * Please see the COPYING and CONTRIBUTORS files for details.
+ */
 
 /*
  * confload.c
@@ -13,14 +20,13 @@
 /* Squid provides a number of portability overrides */
 #include "squid.h"
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
+#include <cassert>
+#include <cerrno>
+#include <cstdlib>
+#include <cstring>
 #include <syslog.h>
-#include <errno.h>
 #include <sys/param.h>
 #include <netdb.h>
-#include <assert.h>
 
 #include "msntauth.h"
 #include "valid.h"
