@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-2017 The Squid Software Foundation and contributors
+ * Copyright (C) 1996-2014 The Squid Software Foundation and contributors
  *
  * Squid software is distributed under GPLv2+ license and includes
  * contributions from numerous individuals and organizations.
@@ -31,18 +31,18 @@
 
 #include <cstring>
 
-#define NMB_UNICAST     1
-#define NMB_BROADCAST   2
+#define NMB_UNICAST		1
+#define NMB_BROADCAST	2
 
 struct SMBDOMAIN {
-    const char *name;       /* domain name */
-    const char *sname;      /* match this with user input */
-    const char *passthrough;    /* pass-through authentication */
-    const char *nmbaddr;    /* name service address */
-    int nmbcast;        /* broadcast or unicast */
-    char *authshare;        /* share name of auth file */
-    const char *authfile;   /* pathname of auth file */
-    struct SMBDOMAIN *next; /* linked list */
+    const char *name;		/* domain name */
+    const char *sname;		/* match this with user input */
+    const char *passthrough;	/* pass-through authentication */
+    const char *nmbaddr;	/* name service address */
+    int nmbcast;		/* broadcast or unicast */
+    char *authshare;		/* share name of auth file */
+    const char *authfile;	/* pathname of auth file */
+    struct SMBDOMAIN *next;	/* linked list */
 };
 
 struct SMBDOMAIN *firstdom = NULL;
@@ -111,7 +111,8 @@ main(int argc, char *argv[])
             break;
 
         if (strcmp(argv[i], "-W") == 0) {
-            dom = static_cast<struct SMBDOMAIN *>(xmalloc(sizeof(struct SMBDOMAIN)));
+            if ((dom = (struct SMBDOMAIN *) malloc(sizeof(struct SMBDOMAIN))) == NULL)
+                return 1;
 
             dom->name = dom->sname = argv[++i];
             dom->passthrough = "";
@@ -235,7 +236,6 @@ main(int argc, char *argv[])
             SEND_OK("");
         else
             SEND_ERR("");
-    }               /* while (1) */
+    }				/* while (1) */
     return 0;
 }
-
