@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-2017 The Squid Software Foundation and contributors
+ * Copyright (C) 1996-2014 The Squid Software Foundation and contributors
  *
  * Squid software is distributed under GPLv2+ license and includes
  * contributions from numerous individuals and organizations.
@@ -21,7 +21,7 @@
     Bill Welliver 1999
 
  * Distributed freely under the terms of the GNU General Public License,
- * version 2 or later. See the file COPYING for licensing details
+ * version 2. See the file COPYING for licensing details
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -68,7 +68,7 @@ extern char Default_NTDomain[DNLEN+1];
 extern const char * errormsg;
 
 /* Debugging stuff */
-#if defined(__GNUC__)           /* this is really a gcc-ism */
+#if defined(__GNUC__)			/* this is really a gcc-ism */
 #include <unistd.h>
 static char *__foo;
 #define debug(X...) if (debug_enabled) { \
@@ -91,5 +91,6 @@ debug(char *format,...)
 }
 #endif /* __GNUC__ */
 
-#endif
+int Valid_User(char *,char *, char *);
 
+#endif
