@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-2015 The Squid Software Foundation and contributors
+ * Copyright (C) 1996-2014 The Squid Software Foundation and contributors
  *
  * Squid software is distributed under GPLv2+ license and includes
  * contributions from numerous individuals and organizations.
@@ -57,13 +57,12 @@ passwd_auth(char *user, char *passwd)
     struct passwd *pwd;
     pwd = getpwnam(user);
     if (pwd == NULL) {
-        return 0;       /* User does not exist */
+        return 0;		/* User does not exist */
     } else {
-        char *crypted = crypt(passwd, pwd->pw_passwd);
-        if (!crypted || strcmp(pwd->pw_passwd, crypted)) {
-            return 2;       /* Wrong password */
+        if (strcmp(pwd->pw_passwd, (char *) crypt(passwd, pwd->pw_passwd))) {
+            return 2;		/* Wrong password */
         } else {
-            return 1;       /* Authentication Sucessful */
+            return 1;		/* Authentication Sucessful */
         }
     }
 }
@@ -75,13 +74,12 @@ shadow_auth(char *user, char *passwd)
     struct spwd *pwd;
     pwd = getspnam(user);
     if (pwd == NULL) {
-        return passwd_auth(user, passwd);   /* Fall back to passwd_auth */
+        return passwd_auth(user, passwd);	/* Fall back to passwd_auth */
     } else {
-        char *crypted = crypt(passwd, pwd->sp_pwdp);
-        if (!crypted || strcmp(pwd->sp_pwdp, crypted)) {
-            return 2;       /* Wrong password */
+        if (strcmp(pwd->sp_pwdp, crypt(passwd, pwd->sp_pwdp))) {
+            return 2;		/* Wrong password */
         } else {
-            return 1;       /* Authentication Sucessful */
+            return 1;		/* Authentication Sucessful */
         }
     }
 }
@@ -98,7 +96,7 @@ main(int argc, char **argv)
     while (fgets(buf, HELPER_INPUT_BUFFER, stdin) != NULL) {
 
         if ((p = strchr(buf, '\n')) != NULL)
-            *p = '\0';      /* strip \n */
+            *p = '\0';		/* strip \n */
 
         if ((user = strtok(buf, " ")) == NULL) {
             SEND_ERR("No Username");
@@ -127,4 +125,3 @@ main(int argc, char **argv)
     }
     return 0;
 }
-
