@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-2017 The Squid Software Foundation and contributors
+ * Copyright (C) 1996-2014 The Squid Software Foundation and contributors
  *
  * Squid software is distributed under GPLv2+ license and includes
  * contributions from numerous individuals and organizations.
@@ -29,7 +29,7 @@
  * the file format.  However storing such a triple does little to
  * improve security: If compromised the username:realm:HA1 combination
  * is "plaintext equivalent" - for the purposes of digest authentication
- * they allow the user access. Password synchronization is not tackled
+ * they allow the user access. Password syncronisation is not tackled
  * by digest - just preventing on the wire compromise.
  *
  * Copyright (c) 2003  Robert Collins  <robertc@squid-cache.org>
@@ -118,7 +118,7 @@ read_passwd_file(const char *passwordFile, int isHa1Mode)
             u = static_cast<user_data*>(xcalloc(1, sizeof(*u)));
             if (realm) {
                 int len = strlen(user) + strlen(realm) + 2;
-                u->hash.key = xmalloc(len);
+                u->hash.key = malloc(len);
                 snprintf(static_cast<char*>(u->hash.key), len, "%s:%s", user, realm);
             } else {
                 u->hash.key = xstrdup(user);
@@ -195,4 +195,3 @@ TextHHA1(RequestData * requestData)
         DigestCalcHA1("md5", requestData->user, requestData->realm, u->passwd, NULL, NULL, HA1, requestData->HHA1);
     }
 }
-
