@@ -1,4 +1,13 @@
-/* ext_edirectory_userip_acl - Copyright (C) 2009-2011 Chad E. Naugle
+/*
+ * Copyright (C) 1996-2014 The Squid Software Foundation and contributors
+ *
+ * Squid software is distributed under GPLv2+ license and includes
+ * contributions from numerous individuals and organizations.
+ * Please see the COPYING and CONTRIBUTORS files for details.
+ */
+
+/*
+ * Copyright (C) 2009-2011 Chad E. Naugle
  *
  ********************************************************************************
  *
@@ -35,30 +44,19 @@
 #define EDUI_PROGRAM_VERSION		"2.1"
 
 /* System includes */
-#ifdef HAVE_STDIO_H
-#include <stdio.h>
-#endif
 #ifndef _GNU_SOURCE
 #define _GNU_SOURCE
 #endif
 #ifndef __USE_GNU
 #define __USE_GNU
 #endif
-#ifdef HAVE_STDLIB_H
-#include <stdlib.h>
-#endif
-#ifdef HAVE_STRING_H
-#include <string.h>
-#endif
-#ifdef HAVE_CTYPE_H
-#include <ctype.h>
-#endif
-#ifdef HAVE_ERRNO_H
-#include <errno.h>
-#endif
-#ifdef HAVE_SIGNAL_H
-#include <signal.h>
-#endif
+#include <cctype>
+#include <cerrno>
+#include <csignal>
+#include <cstdarg>
+#include <cstdlib>
+#include <cstring>
+#include <ctime>
 #ifdef HAVE_ARPA_INET_H
 #include <arpa/inet.h>
 #endif
@@ -69,12 +67,6 @@
 #ifdef HAVE_LDAP_H
 #include <ldap.h>
 #endif
-#ifdef HAVE_STDARG_H
-#include <stdarg.h>
-#endif
-#ifdef HAVE_TIME_H
-#include <time.h>
-#endif
 
 #ifdef HELPER_INPUT_BUFFER
 #define EDUI_MAXLEN		HELPER_INPUT_BUFFER
