@@ -23,6 +23,7 @@ std::queue<char *> ConfigParser::CfgLineTokens_;
 std::queue<std::string> ConfigParser::Undo_;
 bool ConfigParser::AllowMacros_ = false;
 bool ConfigParser::ParseQuotedOrToEol_ = false;
+bool ConfigParser::RecognizeQuotedPair_ = false;
 bool ConfigParser::PreviewMode_ = false;
 
 static const char *SQUID_ERROR_TOKEN = "[invalid token]";
@@ -108,7 +109,7 @@ ConfigParser::strtokFile()
                 *t = '\0';
 
                 if ((wordFile = fopen(fn, "r")) == NULL) {
-                    debugs(3, DBG_CRITICAL, "Can not open file " << t << " for reading");
+                    debugs(3, DBG_CRITICAL, "ERROR: Can not open file " << fn << " for reading");
                     return NULL;
                 }
 
@@ -217,7 +218,7 @@ ConfigParser::UnQuote(const char *token, const char **next)
         if (PreviewMode_)
             strncpy(UnQuoted, SQUID_ERROR_TOKEN, sizeof(UnQuoted));
         else {
-            debugs(3, DBG_CRITICAL, errorStr << ": " << errorPos);
+            debugs(3, DBG_CRITICAL, "FATAL: " << errorStr << ": " << errorPos);
             self_destruct();
         }
     }
@@ -261,12 +262,25 @@ ConfigParser::TokenParse(const char * &nextToken, ConfigParser::TokenType &type)
     const char *sep;
     if (ConfigParser::ParseQuotedOrToEol_)
         sep = "\n";
+    else if (ConfigParser::RecognizeQuotedPair_)
+        sep = w_space "\\";
     else if (!ConfigParser::RecognizeQuotedValues || *nextToken == '(')
         sep = w_space;
     else
         sep = w_space "(";
     nextToken += strcspn(nextToken, sep);
 
+    while (ConfigParser::RecognizeQuotedPair_ && *nextToken == '\\') {
+        // NP: do not permit \0 terminator to be escaped.
+        if (*(nextToken+1) && *(nextToken+1) != '\r' && *(nextToken+1) != '\n') {
+          nextToken += 2; // skip the quoted-pair (\-escaped) character
+          nextToken += strcspn(nextToken, sep);
+        } else {
+            debugs(3, DBG_CRITICAL, "FATAL: Unescaped '\' character in regex pattern: " << tokenStart);
+            self_destruct();
+        }
+    }
+
     if (ConfigParser::RecognizeQuotedValues && *nextToken == '(') {
         if (strncmp(tokenStart, "parameters", nextToken - tokenStart) == 0)
             type = ConfigParser::FunctionParameters;
@@ -276,7 +290,7 @@ ConfigParser::TokenParse(const char * &nextToken, ConfigParser::TokenType &type)
                 CfgLineTokens_.push(err);
                 return err;
             } else {
-                debugs(3, DBG_CRITICAL, "Unknown cfg function: " << tokenStart);
+                debugs(3, DBG_CRITICAL, "FATAL: Unknown cfg function: " << tokenStart);
                 self_destruct();
             }
         }
@@ -300,7 +314,7 @@ ConfigParser::TokenParse(const char * &nextToken, ConfigParser::TokenType &type)
                         CfgLineTokens_.push(err);
                         return err;
                     } else {
-                        debugs(3, DBG_CRITICAL, "Not alphanumeric character '"<< *s << "' in unquoted token " << tokenStart);
+                        debugs(3, DBG_CRITICAL, "FATAL: Not alphanumeric character '"<< *s << "' in unquoted token " << tokenStart);
                         self_destruct();
                     }
                 }
@@ -363,7 +377,7 @@ ConfigParser::NextToken()
 
             char *path = NextToken();
             if (LastTokenType != ConfigParser::QuotedToken) {
-                debugs(3, DBG_CRITICAL, "Quoted filename missing: " << token);
+                debugs(3, DBG_CRITICAL, "FATAL: Quoted filename missing: " << token);
                 self_destruct();
                 return NULL;
             }
@@ -372,20 +386,20 @@ ConfigParser::NextToken()
             char *end = NextToken();
             ConfigParser::PreviewMode_ = savePreview;
             if (LastTokenType != ConfigParser::SimpleToken || strcmp(end, ")") != 0) {
-                debugs(3, DBG_CRITICAL, "missing ')' after " << token << "(\"" << path << "\"");
+                debugs(3, DBG_CRITICAL, "FATAL: missing ')' after " << token << "(\"" << path << "\"");
                 self_destruct();
                 return NULL;
             }
 
             if (CfgFiles.size() > 16) {
-                debugs(3, DBG_CRITICAL, "WARNING: can't open %s for reading parameters: includes are nested too deeply (>16)!\n" << path);
+                debugs(3, DBG_CRITICAL, "FATAL: can't open %s for reading parameters: includes are nested too deeply (>16)!\n" << path);
                 self_destruct();
                 return NULL;
             }
 
             ConfigParser::CfgFile *wordfile = new ConfigParser::CfgFile();
             if (!path || !wordfile->startParse(path)) {
-                debugs(3, DBG_CRITICAL, "Error opening config file: " << token);
+                debugs(3, DBG_CRITICAL, "FATAL: Error opening config file: " << token);
                 delete wordfile;
                 self_destruct();
                 return NULL;
@@ -429,10 +443,12 @@ char *
 ConfigParser::RegexStrtokFile()
 {
     if (ConfigParser::RecognizeQuotedValues) {
-        debugs(3, DBG_CRITICAL, "Can not read regex expresion while configuration_includes_quoted_values is enabled");
+        debugs(3, DBG_CRITICAL, "FATAL: Can not read regex expression while configuration_includes_quoted_values is enabled");
         self_destruct();
     }
+    ConfigParser::RecognizeQuotedPair_ = true;
     char * token = strtokFile();
+    ConfigParser::RecognizeQuotedPair_ = false;
     return token;
 }
 
@@ -440,11 +456,12 @@ char *
 ConfigParser::RegexPattern()
 {
     if (ConfigParser::RecognizeQuotedValues) {
-        debugs(3, DBG_CRITICAL, "Can not read regex expresion while configuration_includes_quoted_values is enabled");
+        debugs(3, DBG_CRITICAL, "FATAL: Can not read regex expression while configuration_includes_quoted_values is enabled");
         self_destruct();
     }
-
+    ConfigParser::RecognizeQuotedPair_ = true;
     char * token = NextToken();
+    ConfigParser::RecognizeQuotedPair_ = false;
     return token;
 }
 
@@ -488,7 +505,7 @@ ConfigParser::CfgFile::startParse(char *path)
     assert(wordFile == NULL);
     debugs(3, 3, "Parsing from " << path);
     if ((wordFile = fopen(path, "r")) == NULL) {
-        debugs(3, DBG_CRITICAL, "file :" << path << " not found");
+        debugs(3, DBG_CRITICAL, "WARNING: file :" << path << " not found");
         return false;
     }
 
