@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-2017 The Squid Software Foundation and contributors
+ * Copyright (C) 1996-2014 The Squid Software Foundation and contributors
  *
  * Squid software is distributed under GPLv2+ license and includes
  * contributions from numerous individuals and organizations.
@@ -35,15 +35,15 @@ DelayTagged::DelayTagged()
     DelayPools::registerForUpdates (this);
 }
 
-static Splay<DelayTaggedBucket::Pointer>::SPLAYFREE DelayTaggedFree;
+static SplayNode<DelayTaggedBucket::Pointer>::SPLAYFREE DelayTaggedFree;
 
 DelayTagged::~DelayTagged()
 {
     DelayPools::deregisterForUpdates (this);
-    buckets.destroy(DelayTaggedFree);
+    buckets.head->destroy (DelayTaggedFree);
 }
 
-static Splay<DelayTaggedBucket::Pointer>::SPLAYCMP DelayTaggedCmp;
+static SplayNode<DelayTaggedBucket::Pointer>::SPLAYCMP DelayTaggedCmp;
 
 int
 DelayTaggedCmp(DelayTaggedBucket::Pointer const &left, DelayTaggedBucket::Pointer const &right)
@@ -56,13 +56,11 @@ void
 DelayTaggedFree(DelayTaggedBucket::Pointer &)
 {}
 
-struct DelayTaggedStatsVisitor {
-    StoreEntry *sentry;
-    explicit DelayTaggedStatsVisitor(StoreEntry *se): sentry(se) {}
-    void operator() (DelayTaggedBucket::Pointer const &current) {
-        current->stats(sentry);
-    }
-};
+void
+DelayTaggedStatsWalkee(DelayTaggedBucket::Pointer const &current, void *state)
+{
+    current->stats ((StoreEntry *)state);
+}
 
 void
 DelayTagged::stats(StoreEntry * sentry)
@@ -74,13 +72,12 @@ DelayTagged::stats(StoreEntry * sentry)
 
     storeAppendPrintf(sentry, "\t\tCurrent: ");
 
-    if (buckets.empty()) {
+    if (!buckets.head) {
         storeAppendPrintf (sentry, "Not used yet.\n\n");
         return;
     }
 
-    DelayTaggedStatsVisitor visitor(sentry);
-    buckets.visit(visitor);
+    buckets.head->walk(DelayTaggedStatsWalkee, sentry);
     storeAppendPrintf(sentry, "\n\n");
 }
 
@@ -105,20 +102,11 @@ DelayTaggedUpdateWalkee(DelayTaggedBucket::Pointer const &current, void *state)
     const_cast<DelayTaggedBucket *>(current.getRaw())->theBucket.update(t->spec, t->incr);
 }
 
-struct DelayTaggedUpdateVisitor {
-    DelayTaggedUpdater *updater;
-    explicit DelayTaggedUpdateVisitor(DelayTaggedUpdater *u) : updater(u) {}
-    void operator() (DelayTaggedBucket::Pointer const &current) {
-        const_cast<DelayTaggedBucket *>(current.getRaw())->theBucket.update(updater->spec, updater->incr);
-    }
-};
-
 void
 DelayTagged::update(int incr)
 {
     DelayTaggedUpdater updater(spec, incr);
-    DelayTaggedUpdateVisitor visitor(&updater);
-    buckets.visit(visitor);
+    buckets.head->walk (DelayTaggedUpdateWalkee, &updater);
     kickReads();
 }
 
@@ -194,7 +182,7 @@ DelayTagged::Id::Id(DelayTagged::Pointer aDelayTagged, String &aTag) : theTagged
     }
 
     theBucket->theBucket.init(theTagged->spec);
-    theTagged->buckets.insert (theBucket, DelayTaggedCmp);
+    theTagged->buckets.head = theTagged->buckets.head->insert (theBucket, DelayTaggedCmp);
 }
 
 DelayTagged::Id::~Id()
@@ -221,4 +209,3 @@ DelayTagged::Id::delayRead(DeferredRead const &aRead)
 }
 
 #endif
-
