@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-2017 The Squid Software Foundation and contributors
+ * Copyright (C) 1996-2014 The Squid Software Foundation and contributors
  *
  * Squid software is distributed under GPLv2+ license and includes
  * contributions from numerous individuals and organizations.
@@ -22,7 +22,7 @@
 #include <fcntl.h>
 #include <dirent.h>
 
-#define RIDICULOUS_LENGTH   4096
+#define RIDICULOUS_LENGTH	4096
 
 enum _squidaio_thread_status {
     _THREAD_STARTING = 0,
@@ -62,7 +62,7 @@ typedef struct squidaio_request_queue_t {
     squidaio_request_t *volatile head;
     squidaio_request_t *volatile *volatile tailp;
     unsigned long requests;
-    unsigned long blocked;  /* main failed to lock the queue */
+    unsigned long blocked;	/* main failed to lock the queue */
 } squidaio_request_queue_t;
 
 typedef struct squidaio_thread_t squidaio_thread_t;
@@ -97,16 +97,16 @@ static squidaio_thread_t *threads = NULL;
 static int squidaio_initialised = 0;
 
 #define AIO_LARGE_BUFS  16384
-#define AIO_MEDIUM_BUFS AIO_LARGE_BUFS >> 1
-#define AIO_SMALL_BUFS  AIO_LARGE_BUFS >> 2
-#define AIO_TINY_BUFS   AIO_LARGE_BUFS >> 3
-#define AIO_MICRO_BUFS  128
+#define AIO_MEDIUM_BUFS	AIO_LARGE_BUFS >> 1
+#define AIO_SMALL_BUFS	AIO_LARGE_BUFS >> 2
+#define AIO_TINY_BUFS	AIO_LARGE_BUFS >> 3
+#define AIO_MICRO_BUFS	128
 
-static MemAllocator *squidaio_large_bufs = NULL;    /* 16K */
-static MemAllocator *squidaio_medium_bufs = NULL;   /* 8K */
-static MemAllocator *squidaio_small_bufs = NULL;    /* 4K */
-static MemAllocator *squidaio_tiny_bufs = NULL; /* 2K */
-static MemAllocator *squidaio_micro_bufs = NULL;    /* 128K */
+static MemAllocator *squidaio_large_bufs = NULL;	/* 16K */
+static MemAllocator *squidaio_medium_bufs = NULL;	/* 8K */
+static MemAllocator *squidaio_small_bufs = NULL;	/* 4K */
+static MemAllocator *squidaio_tiny_bufs = NULL;	/* 2K */
+static MemAllocator *squidaio_micro_bufs = NULL;	/* 128K */
 
 static int request_queue_len = 0;
 static MemAllocator *squidaio_request_pool = NULL;
@@ -485,7 +485,7 @@ squidaio_thread_loop(LPVOID lpParam)
                 squidaio_do_unlink(request);
                 break;
 
-#if AIO_OPENDIR         /* Opendir not implemented yet */
+#if AIO_OPENDIR			/* Opendir not implemented yet */
 
             case _AIO_OP_OPENDIR:
                 squidaio_do_opendir(request);
@@ -501,7 +501,7 @@ squidaio_thread_loop(LPVOID lpParam)
                 request->err = EINVAL;
                 break;
             }
-        } else {        /* cancelled */
+        } else {		/* cancelled */
             request->ret = -1;
             request->err = EINTR;
         }
@@ -526,12 +526,12 @@ squidaio_thread_loop(LPVOID lpParam)
         CommIO::NotifyIOCompleted();
         Sleep(0);
         ++ threadp->requests;
-    }               /* while forever */
+    }				/* while forever */
 
     CloseHandle(cond);
 
     return 0;
-}               /* squidaio_thread_loop */
+}				/* squidaio_thread_loop */
 
 static void
 squidaio_queue_request(squidaio_request_t * request)
@@ -581,13 +581,13 @@ squidaio_queue_request(squidaio_request_t * request)
     }
 
     if (request_queue2.head) {
-        static uint64_t filter = 0;
-        static uint64_t filter_limit = 8196;
+        static int filter = 0;
+        static int filter_limit = 8;
 
         if (++filter >= filter_limit) {
             filter_limit += filter;
             filter = 0;
-            debugs(43, DBG_IMPORTANT, "squidaio_queue_request: WARNING - Queue congestion (growing to " << filter_limit << ")");
+            debugs(43, DBG_IMPORTANT, "squidaio_queue_request: WARNING - Queue congestion");
         }
     }
 
@@ -631,7 +631,7 @@ squidaio_queue_request(squidaio_request_t * request)
         squidaio_sync();
         debugs(43, DBG_CRITICAL, "squidaio_queue_request: Synced");
     }
-}               /* squidaio_queue_request */
+}				/* squidaio_queue_request */
 
 static void
 squidaio_cleanup_request(squidaio_request_t * requestp)
@@ -694,7 +694,7 @@ squidaio_cleanup_request(squidaio_request_t * requestp)
     }
 
     squidaio_request_pool->freeOne(requestp);
-}               /* squidaio_cleanup_request */
+}				/* squidaio_cleanup_request */
 
 int
 squidaio_cancel(squidaio_result_t * resultp)
@@ -711,7 +711,7 @@ squidaio_cancel(squidaio_result_t * resultp)
     }
 
     return 1;
-}               /* squidaio_cancel */
+}				/* squidaio_cancel */
 
 int
 squidaio_open(const char *path, int oflag, mode_t mode, squidaio_result_t * resultp)
@@ -1044,7 +1044,7 @@ AIO_REPOLL:
         goto AIO_REPOLL;
 
     return resultp;
-}               /* squidaio_poll_done */
+}				/* squidaio_poll_done */
 
 int
 squidaio_operations_pending(void)
@@ -1120,4 +1120,3 @@ squidaio_stats(StoreEntry * sentry)
         threadp = threadp->next;
     }
 }
-
