@@ -1,4 +1,12 @@
-#include "squid-old.h"
+/*
+ * Copyright (C) 1996-2014 The Squid Software Foundation and contributors
+ *
+ * Squid software is distributed under GPLv2+ license and includes
+ * contributions from numerous individuals and organizations.
+ * Please see the COPYING and CONTRIBUTORS files for details.
+ */
+
+#include "squid.h"
 #include "IpcIoDiskIOModule.h"
 #include "IpcIoIOStrategy.h"
 
@@ -18,10 +26,9 @@ IpcIoDiskIOModule::init()
 {}
 
 void
-IpcIoDiskIOModule::shutdown()
+IpcIoDiskIOModule::gracefulShutdown()
 {}
 
-
 DiskIOStrategy*
 IpcIoDiskIOModule::createStrategy()
 {
