@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-2017 The Squid Software Foundation and contributors
+ * Copyright (C) 1996-2014 The Squid Software Foundation and contributors
  *
  * Squid software is distributed under GPLv2+ license and includes
  * contributions from numerous individuals and organizations.
@@ -88,7 +88,7 @@ bool
 HttpHdrCc::parse(const String & str)
 {
     const char *item;
-    const char *p;      /* '=' parameter */
+    const char *p;		/* '=' parameter */
     const char *pos = NULL;
     http_hdr_cc_type type;
     int ilen;
@@ -257,27 +257,6 @@ HttpHdrCc::packInto(Packer * p) const
 
             /* for all options having values, "=value" after the name */
             switch (flag) {
-            case CC_BADHDR:
-                break;
-            case CC_PUBLIC:
-                break;
-            case CC_PRIVATE:
-                if (private_.size())
-                    packerPrintf(p, "=\"" SQUIDSTRINGPH "\"", SQUIDSTRINGPRINT(private_));
-                break;
-
-            case CC_NO_CACHE:
-                if (noCache().size())
-                    packerPrintf(p, "=\"" SQUIDSTRINGPH "\"", SQUIDSTRINGPRINT(noCache()));
-                break;
-            case CC_NO_STORE:
-                break;
-            case CC_NO_TRANSFORM:
-                break;
-            case CC_MUST_REVALIDATE:
-                break;
-            case CC_PROXY_REVALIDATE:
-                break;
             case CC_MAX_AGE:
                 packerPrintf(p, "=%d", (int) maxAge());
                 break;
@@ -293,14 +272,8 @@ HttpHdrCc::packInto(Packer * p) const
             case CC_MIN_FRESH:
                 packerPrintf(p, "=%d", (int) minFresh());
                 break;
-            case CC_ONLY_IF_CACHED:
-                break;
-            case CC_STALE_IF_ERROR:
-                packerPrintf(p, "=%d", staleIfError());
-                break;
-            case CC_OTHER:
-            case CC_ENUM_END:
-                // done below after the loop
+            default:
+                /* do nothing, directive was already printed */
                 break;
             }
 
@@ -327,7 +300,7 @@ httpHdrCcUpdateStats(const HttpHdrCc * cc, StatHist * hist)
 void
 httpHdrCcStatDumper(StoreEntry * sentry, int idx, double val, double size, int count)
 {
-    extern const HttpHeaderStat *dump_stat; /* argh! */
+    extern const HttpHeaderStat *dump_stat;	/* argh! */
     const int id = (int) val;
     const int valid_id = id >= 0 && id < CC_ENUM_END;
     const char *name = valid_id ? CcAttrs[id].name : "INVALID";
@@ -340,4 +313,3 @@ httpHdrCcStatDumper(StoreEntry * sentry, int idx, double val, double size, int c
 #if !_USE_INLINE_
 #include "HttpHdrCc.cci"
 #endif
-
