@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-2017 The Squid Software Foundation and contributors
+ * Copyright (C) 1996-2014 The Squid Software Foundation and contributors
  *
  * Squid software is distributed under GPLv2+ license and includes
  * contributions from numerous individuals and organizations.
@@ -10,7 +10,6 @@
 
 #include "squid.h"
 #include "Debug.h"
-#include "HttpHdrCc.h"
 #include "HttpHeaderTools.h"
 #include "HttpMsg.h"
 #include "MemBuf.h"
@@ -19,8 +18,8 @@
 #include "SquidConfig.h"
 
 HttpMsg::HttpMsg(http_hdr_owner_type owner): header(owner),
-    cache_control(NULL), hdr_sz(0), content_length(0),
-    pstate(psReadyToParseStartLine)
+        cache_control(NULL), hdr_sz(0), content_length(0),
+        pstate(psReadyToParseStartLine)
 {}
 
 HttpMsg::~HttpMsg()
@@ -28,25 +27,6 @@ HttpMsg::~HttpMsg()
     assert(!body_pipe);
 }
 
-void
-HttpMsg::putCc(const HttpHdrCc *otherCc)
-{
-    // get rid of the old CC, if any
-    if (cache_control) {
-        delete cache_control;
-        cache_control = NULL;
-        if (!otherCc)
-            header.delById(HDR_CACHE_CONTROL);
-        // else it will be deleted inside putCc() below
-    }
-
-    // add new CC, if any
-    if (otherCc) {
-        cache_control = new HttpHdrCc(*otherCc);
-        header.putCc(cache_control);
-    }
-}
-
 HttpMsgParseState &operator++ (HttpMsgParseState &aState)
 {
     int tmp = (int)aState;
@@ -89,7 +69,7 @@ httpMsgIsolateHeaders(const char **parse_start, int l, const char **blk_start, c
      * NOT point to a CR or NL character, then return failure
      */
     if (**parse_start != '\r' && **parse_start != '\n')
-        return 0;       /* failure */
+        return 0;		/* failure */
 
     /*
      * If we didn't find the end of headers, and parse_start does point
@@ -355,4 +335,3 @@ void HttpMsg::firstLineBuf(MemBuf& mb)
     packFirstLineInto(&p, true);
     packerClean(&p);
 }
-
