@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-2016 The Squid Software Foundation and contributors
+ * Copyright (C) 1996-2014 The Squid Software Foundation and contributors
  *
  * Squid software is distributed under GPLv2+ license and includes
  * contributions from numerous individuals and organizations.
@@ -59,7 +59,7 @@ public:
     /** \par public, writable, but use httpReply* interfaces when possible */
     Http::StatusLine sline;
 
-    HttpBody body;      /**< for small constant memory-resident text bodies only */
+    HttpBody body;		/**< for small constant memory-resident text bodies only */
 
     String protoPrefix;         /**< e.g., "HTTP/"  */
 
@@ -72,7 +72,7 @@ public:
 
     virtual bool inheritProperties(const HttpMsg *aMsg);
 
-    bool updateOnNotModified(HttpReply const *other);
+    void updateOnNotModified(HttpReply const *other);
 
     /** set commonly used info with one call */
     void setHeaders(Http::StatusCode status,
@@ -112,10 +112,6 @@ public:
 
     virtual void hdrCacheInit();
 
-    /// whether our Date header value is smaller than theirs
-    /// \returns false if any information is missing
-    bool olderThan(const HttpReply *them) const;
-
 private:
     /** initialize */
     void init();
@@ -151,4 +147,3 @@ protected:
 MEMPROXY_CLASS_INLINE(HttpReply);
 
 #endif /* SQUID_HTTPREPLY_H */
-
