@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-2016 The Squid Software Foundation and contributors
+ * Copyright (C) 1996-2014 The Squid Software Foundation and contributors
  *
  * Squid software is distributed under GPLv2+ license and includes
  * contributions from numerous individuals and organizations.
@@ -23,7 +23,6 @@
 #include "MemObject.h"
 #include "Range.h"
 #include "RemovalPolicy.h"
-#include "store_key_md5.h"
 #include "StoreIOBuffer.h"
 #include "StoreStats.h"
 
@@ -74,8 +73,6 @@ public:
     }
     virtual bool isAccepting() const;
     virtual size_t bytesWanted(Range<size_t> const aRange, bool ignoreDelayPool = false) const;
-    /// flags [truncated or too big] entry with ENTRY_BAD_LENGTH and releases it
-    void lengthWentBad(const char *reason);
     virtual void complete();
     virtual store_client_t storeClientType() const;
     virtual char const *getSerialisedMetaData();
@@ -94,18 +91,14 @@ public:
 
     void abort();
     void unlink();
-    void makePublic(const KeyScope keyScope = ksDefault);
+    void makePublic();
     void makePrivate();
-    void setPublicKey(const KeyScope keyScope = ksDefault);
-    /// Resets existing public key to a public key with default scope,
-    /// releasing the old default-scope entry (if any).
-    /// Does nothing if the existing public key already has default scope.
-    void clearPublicKeyScope();
+    void setPublicKey();
     void setPrivateKey();
     void expireNow();
     void releaseRequest();
     void negativeCache();
-    void cacheNegatively();     /** \todo argh, why both? */
+    void cacheNegatively();		/** \todo argh, why both? */
     void invokeHandlers();
     void purgeMem();
     void cacheInMemory(); ///< start or continue storing in memory cache
@@ -135,7 +128,7 @@ public:
     void registerAbort(STABH * cb, void *);
     void reset();
     void setMemStatus(mem_status_t);
-    bool timestampsSet();
+    void timestampsSet();
     void unregisterAbort();
     void destroyMemObject();
     int checkTooSmall();
@@ -143,16 +136,7 @@ public:
     void delayAwareRead(const Comm::ConnectionPointer &conn, char *buf, int len, AsyncCall::Pointer callback);
 
     void setNoDelay (bool const);
-    void lastModified(const time_t when) { lastModified_ = when; }
-    /// \returns entry's 'effective' modification time
-    time_t lastModified() const {
-        // may still return -1 if timestamp is not set
-        return lastModified_ < 0 ? timestamp : lastModified_;
-    }
-    /// \returns a formatted string with entry's timestamps
-    const char *describeTimestamps() const;
-    // TODO: consider removing currently unsupported imslen parameter
-    bool modifiedSince(const time_t ims, const int imslen = -1) const;
+    bool modifiedSince(HttpRequest * request) const;
     /// has ETag matching at least one of the If-Match etags
     bool hasIfMatchEtag(const HttpRequest &request) const;
     /// has ETag matching at least one of the If-None-Match etags
@@ -169,9 +153,7 @@ public:
     time_t timestamp;
     time_t lastref;
     time_t expires;
-private:
-    time_t lastModified_; ///< received Last-Modified value or -1; use lastModified()
-public:
+    time_t lastmod;
     uint64_t swap_file_sz;
     uint16_t refcount;
     uint16_t flags;
@@ -244,13 +226,10 @@ protected:
 
 private:
     bool checkTooBig() const;
-    void forcePublicKey(const cache_key *newkey);
-    void adjustVary();
-    const cache_key *calcPublicKey(const KeyScope keyScope);
 
     static MemAllocator *pool;
 
-    unsigned short lock_count;      /* Assume < 65536! */
+    unsigned short lock_count;		/* Assume < 65536! */
 
 #if USE_ADAPTATION
     /// producer callback registered with deferProducer
@@ -380,7 +359,7 @@ public:
     virtual StoreSearch *search(String const url, HttpRequest *) = 0;
 
     /* pulled up from SwapDir for migration.... probably do not belong here */
-    virtual void reference(StoreEntry &) = 0;   /* Reference this object */
+    virtual void reference(StoreEntry &) = 0;	/* Reference this object */
 
     /// Undo reference(), returning false iff idle e should be destroyed
     virtual bool dereference(StoreEntry &e, bool wantsLocalMemory) = 0;
@@ -449,9 +428,6 @@ public:
     /// update a local collapsed entry with fresh info from this cache (if any)
     virtual bool updateCollapsed(StoreEntry &collapsed) { return false; }
 
-    /// whether this storage is capable of serving multiple workers
-    virtual bool smpAware() const = 0;
-
 private:
     static RefCount<Store> CurrentRoot;
 };
@@ -472,10 +448,10 @@ void storeEntryReplaceObject(StoreEntry *, HttpReply *);
 StoreEntry *storeGetPublic(const char *uri, const HttpRequestMethod& method);
 
 /// \ingroup StoreAPI
-StoreEntry *storeGetPublicByRequest(HttpRequest * request, const KeyScope keyScope = ksDefault);
+StoreEntry *storeGetPublicByRequest(HttpRequest * request);
 
 /// \ingroup StoreAPI
-StoreEntry *storeGetPublicByRequestMethod(HttpRequest * request, const HttpRequestMethod& method, const KeyScope keyScope = ksDefault);
+StoreEntry *storeGetPublicByRequestMethod(HttpRequest * request, const HttpRequestMethod& method);
 
 /// \ingroup StoreAPI
 /// Like storeCreatePureEntry(), but also locks the entry and sets entry key.
@@ -535,4 +511,3 @@ void packerToStoreInit(Packer * p, StoreEntry * e);
 void storeGetMemSpace(int size);
 
 #endif /* SQUID_STORE_H */
-
