@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-2017 The Squid Software Foundation and contributors
+ * Copyright (C) 1996-2014 The Squid Software Foundation and contributors
  *
  * Squid software is distributed under GPLv2+ license and includes
  * contributions from numerous individuals and organizations.
@@ -18,19 +18,15 @@ StoreMetaVary::checkConsistency(StoreEntry *e) const
 {
     assert (getType() == STORE_META_VARY_HEADERS);
 
-    if (e->mem_obj->vary_headers.isEmpty()) {
+    if (!e->mem_obj->vary_headers) {
         /* XXX separate this mutator from the query */
         /* Assume the object is OK.. remember the vary request headers */
-        e->mem_obj->vary_headers.assign(static_cast<const char *>(value), length);
-        /* entries created before SBuf vary handling may include string terminator */
-        static const SBuf nul("\0", 1);
-        e->mem_obj->vary_headers.trim(nul);
+        e->mem_obj->vary_headers = xstrdup((char *)value);
         return true;
     }
 
-    if (e->mem_obj->vary_headers.cmp(static_cast<const char *>(value), length) != 0)
+    if (strcmp(e->mem_obj->vary_headers, (char *)value) != 0)
         return false;
 
     return true;
 }
-
