@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-2017 The Squid Software Foundation and contributors
+ * Copyright (C) 1996-2014 The Squid Software Foundation and contributors
  *
  * Squid software is distributed under GPLv2+ license and includes
  * contributions from numerous individuals and organizations.
@@ -71,20 +71,25 @@ ACLCertificateData::match(X509 *cert)
     return values.match(value);
 }
 
+static void
+aclDumpAttributeListWalkee(char * const & node_data, void *outlist)
+{
+    /* outlist is really a SBufList * */
+    static_cast<SBufList *>(outlist)->push_back(SBuf(node_data));
+}
+
 SBufList
 ACLCertificateData::dump() const
 {
     SBufList sl;
     if (validAttributesStr)
         sl.push_back(SBuf(attribute));
-
-#if __cplusplus >= 201103L
-    sl.splice(sl.end(),values.dump());
-#else
-    // temp is needed until c++11 move constructor
-    SBufList tmp = values.dump();
-    sl.splice(sl.end(),tmp);
-#endif
+    /* damn this is VERY inefficient for long ACL lists... filling
+     * a wordlist this way costs Sum(1,N) iterations. For instance
+     * a 1000-elements list will be filled in 499500 iterations.
+     */
+    /* XXX FIXME: don't break abstraction */
+    values.values->walk(aclDumpAttributeListWalkee, &sl);
     return sl;
 }
 
@@ -126,29 +131,8 @@ ACLCertificateData::parse()
                     debugs(28, DBG_CRITICAL, "FATAL: An acl must use consistent attributes in all config lines (" << newAttribute << "!=" << attribute << ").");
                     self_destruct();
                 }
-            } else {
-                if (strcasecmp(newAttribute, "DN") != 0) {
-                    int nid = OBJ_txt2nid(newAttribute);
-                    if (nid == 0) {
-                        const size_t span = strspn(newAttribute, "0123456789.");
-                        if(newAttribute[span] == '\0') { // looks like a numerical OID
-                            // create a new object based on this attribute
-
-                            // NOTE: Not a [bad] leak: If the same attribute
-                            // has been added before, the OBJ_txt2nid call
-                            // would return a valid nid value.
-                            // TODO: call OBJ_cleanup() on reconfigure?
-                            nid = OBJ_create(newAttribute, newAttribute,  newAttribute);
-                            debugs(28, 7, "New SSL certificate attribute created with name: " << newAttribute << " and nid: " << nid);
-                        }
-                    }
-                    if (nid == 0) {
-                        debugs(28, DBG_CRITICAL, "FATAL: Not valid SSL certificate attribute name or numerical OID: " << newAttribute);
-                        self_destruct();
-                    }
-                }
+            } else
                 attribute = xstrdup(newAttribute);
-            }
         }
     }
 
@@ -167,4 +151,3 @@ ACLCertificateData::clone() const
     /* Splay trees don't clone yet. */
     return new ACLCertificateData(*this);
 }
-
