@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-2017 The Squid Software Foundation and contributors
+ * Copyright (C) 1996-2014 The Squid Software Foundation and contributors
  *
  * Squid software is distributed under GPLv2+ license and includes
  * contributions from numerous individuals and organizations.
@@ -11,8 +11,7 @@
 
 #include "acl/Acl.h"
 #include "acl/Checklist.h"
-
-#include <set>
+#include "splay.h"
 
 namespace Eui
 {
@@ -28,7 +27,7 @@ public:
 
     ACLEui64(char const *);
     ACLEui64(ACLEui64 const &);
-    ~ACLEui64() {}
+    ~ACLEui64();
     ACLEui64&operator=(ACLEui64 const &);
 
     virtual ACL *clone()const;
@@ -41,12 +40,10 @@ public:
 protected:
     static Prototype RegistryProtoype;
     static ACLEui64 RegistryEntry_;
-    typedef std::set<Eui::Eui64> Eui64Data_t;
-    Eui64Data_t eui64Data;
+    SplayNode<Eui::Eui64 *> *data;
     char const *class_;
 };
 
 MEMPROXY_CLASS_INLINE(ACLEui64);
 
 #endif /* SQUID_ACLEUI64_H */
-
