@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-2017 The Squid Software Foundation and contributors
+ * Copyright (C) 1996-2014 The Squid Software Foundation and contributors
  *
  * Squid software is distributed under GPLv2+ license and includes
  * contributions from numerous individuals and organizations.
@@ -23,23 +23,23 @@
 CBDATA_CLASS_INIT(ACLFilledChecklist);
 
 ACLFilledChecklist::ACLFilledChecklist() :
-    dst_peer(NULL),
-    dst_rdns(NULL),
-    request (NULL),
-    reply (NULL),
+        dst_peer(NULL),
+        dst_rdns(NULL),
+        request (NULL),
+        reply (NULL),
 #if USE_AUTH
-    auth_user_request (NULL),
+        auth_user_request (NULL),
 #endif
 #if SQUID_SNMP
-    snmp_community(NULL),
+        snmp_community(NULL),
 #endif
 #if USE_OPENSSL
-    sslErrors(NULL),
+        sslErrors(NULL),
 #endif
-    conn_(NULL),
-    fd_(-1),
-    destinationDomainChecked_(false),
-    sourceDomainChecked_(false)
+        conn_(NULL),
+        fd_(-1),
+        destinationDomainChecked_(false),
+        sourceDomainChecked_(false)
 {
     my_addr.setEmpty();
     src_addr.setEmpty();
@@ -69,7 +69,7 @@ ACLFilledChecklist::~ACLFilledChecklist()
 ConnStateData *
 ACLFilledChecklist::conn() const
 {
-    return cbdataReferenceValid(conn_) ? conn_ : NULL;
+    return  conn_;
 }
 
 void
@@ -84,15 +84,13 @@ ACLFilledChecklist::conn(ConnStateData *aConn)
 int
 ACLFilledChecklist::fd() const
 {
-    const ConnStateData *c = conn();
-    return (c != NULL && c->clientConnection != NULL) ? c->clientConnection->fd : fd_;
+    return (conn_ != NULL && conn_->clientConnection != NULL) ? conn_->clientConnection->fd : fd_;
 }
 
 void
 ACLFilledChecklist::fd(int aDescriptor)
 {
-    const ConnStateData *c = conn();
-    assert(!c || !c->clientConnection || c->clientConnection->fd == aDescriptor);
+    assert(!conn() || conn()->clientConnection == NULL || conn()->clientConnection->fd == aDescriptor);
     fd_ = aDescriptor;
 }
 
@@ -137,23 +135,23 @@ ACLFilledChecklist::markSourceDomainChecked()
  *    checkCallback() will delete the list (i.e., self).
  */
 ACLFilledChecklist::ACLFilledChecklist(const acl_access *A, HttpRequest *http_request, const char *ident):
-    dst_peer(NULL),
-    dst_rdns(NULL),
-    request(NULL),
-    reply(NULL),
+        dst_peer(NULL),
+        dst_rdns(NULL),
+        request(NULL),
+        reply(NULL),
 #if USE_AUTh
-    auth_user_request(NULL),
+        auth_user_request(NULL),
 #endif
 #if SQUID_SNMP
-    snmp_community(NULL),
+        snmp_community(NULL),
 #endif
 #if USE_OPENSSL
-    sslErrors(NULL),
+        sslErrors(NULL),
 #endif
-    conn_(NULL),
-    fd_(-1),
-    destinationDomainChecked_(false),
-    sourceDomainChecked_(false)
+        conn_(NULL),
+        fd_(-1),
+        destinationDomainChecked_(false),
+        sourceDomainChecked_(false)
 {
     my_addr.setEmpty();
     src_addr.setEmpty();
@@ -184,4 +182,3 @@ ACLFilledChecklist::ACLFilledChecklist(const acl_access *A, HttpRequest *http_re
         xstrncpy(rfc931, ident, USER_IDENT_SZ);
 #endif
 }
-
