@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-2017 The Squid Software Foundation and contributors
+ * Copyright (C) 1996-2014 The Squid Software Foundation and contributors
  *
  * Squid software is distributed under GPLv2+ license and includes
  * contributions from numerous individuals and organizations.
@@ -10,9 +10,7 @@
 #define SQUID_ACLSTRINGDATA_H
 #include "acl/Acl.h"
 #include "acl/Data.h"
-#include "SBuf.h"
-
-#include <set>
+#include "splay.h"
 
 class ACLStringData : public ACLData<char const *>
 {
@@ -20,10 +18,10 @@ class ACLStringData : public ACLData<char const *>
 public:
     MEMPROXY_CLASS(ACLStringData);
 
-    ACLStringData() {}
+    ACLStringData();
     ACLStringData(ACLStringData const &);
     ACLStringData &operator= (ACLStringData const &);
-    virtual ~ACLStringData() {}
+    virtual ~ACLStringData();
     bool match(char const *);
     virtual SBufList dump() const;
     virtual void parse();
@@ -32,9 +30,7 @@ public:
     /// Insert a string data value
     void insert(const char *);
 
-private:
-    typedef std::set<SBuf> StringValues_t;
-    StringValues_t stringValues;
+    SplayNode<char *> *values;
 };
 
 /* TODO move into .cci files */
@@ -42,4 +38,3 @@ private:
 MEMPROXY_CLASS_INLINE(ACLStringData);
 
 #endif /* SQUID_ACLSTRINGDATA_H */
-
