@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-2017 The Squid Software Foundation and contributors
+ * Copyright (C) 1996-2014 The Squid Software Foundation and contributors
  *
  * Squid software is distributed under GPLv2+ license and includes
  * contributions from numerous individuals and organizations.
@@ -7,7 +7,6 @@
  */
 
 #include "squid.h"
-#include "acl/Checklist.h"
 #include "acl/Tree.h"
 #include "wordlist.h"
 
@@ -81,15 +80,3 @@ Acl::Tree::treeDump(const char *prefix, const ActionToString &convert) const
     }
     return text;
 }
-
-bool
-Acl::Tree::bannedAction(ACLChecklist *checklist, Nodes::const_iterator node) const
-{
-    if (actions.size()) {
-        assert(actions.size() == nodes.size());
-        const Nodes::size_type pos = node - nodes.begin();
-        return checklist->bannedAction(actions.at(pos));
-    }
-    return false;
-}
-
