@@ -1,9 +1,18 @@
+/*
+ * Copyright (C) 1996-2014 The Squid Software Foundation and contributors
+ *
+ * Squid software is distributed under GPLv2+ license and includes
+ * contributions from numerous individuals and organizations.
+ * Please see the COPYING and CONTRIBUTORS files for details.
+ */
+
 #ifndef SQUID_ADAPTATION__DYNAMIC_GROUP_CFG_H
 #define SQUID_ADAPTATION__DYNAMIC_GROUP_CFG_H
 
-#include "Array.h"
 #include "SquidString.h"
 
+#include <vector>
+
 namespace Adaptation
 {
 
@@ -11,7 +20,7 @@ namespace Adaptation
 class DynamicGroupCfg
 {
 public:
-    typedef Vector<String> Store;
+    typedef std::vector<String> Store;
     typedef String Id;
 
     Id id; ///< group id
