@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-2017 The Squid Software Foundation and contributors
+ * Copyright (C) 1996-2014 The Squid Software Foundation and contributors
  *
  * Squid software is distributed under GPLv2+ license and includes
  * contributions from numerous individuals and organizations.
@@ -51,16 +51,16 @@ Adaptation::Icap::ModXact::State::State()
 
 Adaptation::Icap::ModXact::ModXact(HttpMsg *virginHeader,
                                    HttpRequest *virginCause, AccessLogEntry::Pointer &alp, Adaptation::Icap::ServiceRep::Pointer &aService):
-    AsyncJob("Adaptation::Icap::ModXact"),
-    Adaptation::Icap::Xaction("Adaptation::Icap::ModXact", aService),
-    virginConsumed(0),
-    bodyParser(NULL),
-    canStartBypass(false), // too early
-    protectGroupBypass(true),
-    replyHttpHeaderSize(-1),
-    replyHttpBodySize(-1),
-    adaptHistoryId(-1),
-    alMaster(alp)
+        AsyncJob("Adaptation::Icap::ModXact"),
+        Adaptation::Icap::Xaction("Adaptation::Icap::ModXact", aService),
+        virginConsumed(0),
+        bodyParser(NULL),
+        canStartBypass(false), // too early
+        protectGroupBypass(true),
+        replyHttpHeaderSize(-1),
+        replyHttpBodySize(-1),
+        adaptHistoryId(-1),
+        alMaster(alp)
 {
     assert(virginHeader);
 
@@ -1259,32 +1259,31 @@ void prepareLogWithRequestDetails(HttpRequest *, AccessLogEntry::Pointer &);
 
 void Adaptation::Icap::ModXact::finalizeLogInfo()
 {
-    HttpRequest *adapted_request_ = NULL;
-    HttpReply *adapted_reply_ = NULL;
-    HttpRequest *virgin_request_ = const_cast<HttpRequest*>(&virginRequest());
+    HttpRequest * request_ = NULL;
+    HttpRequest * adapted_request_ = NULL;
+    HttpReply * reply_ = NULL;
+    request_ = (virgin.cause? virgin.cause: dynamic_cast<HttpRequest*>(virgin.header));
     if (!(adapted_request_ = dynamic_cast<HttpRequest*>(adapted.header))) {
-        // if the request was not adapted, use virgin request to simplify
-        // the code further below
-        adapted_request_ = virgin_request_;
-        adapted_reply_ = dynamic_cast<HttpReply*>(adapted.header);
+        adapted_request_ = request_;
+        reply_ = dynamic_cast<HttpReply*>(adapted.header);
     }
 
-    Adaptation::Icap::History::Pointer h = virgin_request_->icapHistory();
+    Adaptation::Icap::History::Pointer h = (request_ ? request_->icapHistory() : NULL);
     Must(h != NULL); // ICAPXaction::maybeLog calls only if there is a log
     al.icp.opcode = ICP_INVALID;
     al.url = h->log_uri.termedBuf();
     const Adaptation::Icap::ServiceRep  &s = service();
     al.icap.reqMethod = s.cfg().method;
 
-    al.cache.caddr = virgin_request_->client_addr;
+    al.cache.caddr = request_->client_addr;
 
-    al.request = virgin_request_;
+    al.request = request_;
     HTTPMSGLOCK(al.request);
     al.adapted_request = adapted_request_;
     HTTPMSGLOCK(al.adapted_request);
 
-    if (adapted_reply_) {
-        al.reply = adapted_reply_;
+    if (reply_) {
+        al.reply = reply_;
         HTTPMSGLOCK(al.reply);
     } else
         al.reply = NULL;
@@ -1297,30 +1296,25 @@ void Adaptation::Icap::ModXact::finalizeLogInfo()
         al.cache.ssluser = h->ssluser.termedBuf();
 #endif
     al.cache.code = h->logType;
-
-    const HttpMsg *virgin_msg = dynamic_cast<HttpReply*>(virgin.header);
-    if (!virgin_msg)
-        virgin_msg = virgin_request_;
-    assert(virgin_msg != virgin.cause);
-    al.http.clientRequestSz.header = virgin_msg->hdr_sz;
-    if (virgin_msg->body_pipe != NULL)
-        al.http.clientRequestSz.payloadData = virgin_msg->body_pipe->producedSize();
+    // XXX: should use icap-specific counters instead ?
+    al.http.clientRequestSz.payloadData = h->req_sz;
 
     // leave al.icap.bodyBytesRead negative if no body
     if (replyHttpHeaderSize >= 0 || replyHttpBodySize >= 0) {
         const int64_t zero = 0; // to make max() argument types the same
-        const uint64_t headerSize = max(zero, replyHttpHeaderSize);
-        const uint64_t bodySize =  max(zero, replyHttpBodySize);
-        al.icap.bodyBytesRead = headerSize + bodySize;
-        al.http.clientReplySz.header = headerSize;
-        al.http.clientReplySz.payloadData = bodySize;
+        al.icap.bodyBytesRead =
+            max(zero, replyHttpHeaderSize) + max(zero, replyHttpBodySize);
     }
 
-    if (adapted_reply_) {
-        al.http.code = adapted_reply_->sline.status();
-        al.http.content_type = adapted_reply_->content_type.termedBuf();
-        if (replyHttpBodySize >= 0)
+    if (reply_) {
+        al.http.code = reply_->sline.status();
+        al.http.content_type = reply_->content_type.termedBuf();
+        if (replyHttpBodySize >= 0) {
+            // XXX: should use icap-specific counters instead ?
+            al.http.clientReplySz.payloadData = replyHttpBodySize;
+            al.http.clientReplySz.header =  reply_->hdr_sz;
             al.cache.highOffset = replyHttpBodySize;
+        }
         //don't set al.cache.objectSize because it hasn't exist yet
 
         Packer p;
@@ -1329,7 +1323,7 @@ void Adaptation::Icap::ModXact::finalizeLogInfo()
         mb.init();
         packerToMemInit(&p, &mb);
 
-        adapted_reply_->header.packInto(&p);
+        reply_->header.packInto(&p);
         al.headers.reply = xstrdup(mb.buf);
 
         packerClean(&p);
@@ -1815,7 +1809,7 @@ void Adaptation::Icap::ModXact::makeAdaptedBodyPipe(const char *what)
 // TODO: Move SizedEstimate and Preview elsewhere
 
 Adaptation::Icap::SizedEstimate::SizedEstimate()
-    : theData(dtUnexpected)
+        : theData(dtUnexpected)
 {}
 
 void Adaptation::Icap::SizedEstimate::expect(int64_t aSize)
@@ -1961,9 +1955,9 @@ void Adaptation::Icap::ModXact::clearError()
 /* Adaptation::Icap::ModXactLauncher */
 
 Adaptation::Icap::ModXactLauncher::ModXactLauncher(HttpMsg *virginHeader, HttpRequest *virginCause, AccessLogEntry::Pointer &alp, Adaptation::ServicePointer aService):
-    AsyncJob("Adaptation::Icap::ModXactLauncher"),
-    Adaptation::Icap::Launcher("Adaptation::Icap::ModXactLauncher", aService),
-    al(alp)
+        AsyncJob("Adaptation::Icap::ModXactLauncher"),
+        Adaptation::Icap::Launcher("Adaptation::Icap::ModXactLauncher", aService),
+        al(alp)
 {
     virgin.setHeader(virginHeader);
     virgin.setCause(virginCause);
@@ -2001,4 +1995,3 @@ void Adaptation::Icap::ModXactLauncher::updateHistory(bool doStart)
         }
     }
 }
-
