@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-2017 The Squid Software Foundation and contributors
+ * Copyright (C) 1996-2014 The Squid Software Foundation and contributors
  *
  * Squid software is distributed under GPLv2+ license and includes
  * contributions from numerous individuals and organizations.
@@ -33,28 +33,28 @@
 #include "SquidTime.h"
 
 Adaptation::Icap::Xaction::Xaction(const char *aTypeName, Adaptation::Icap::ServiceRep::Pointer &aService):
-    AsyncJob(aTypeName),
-    Adaptation::Initiate(aTypeName),
-    icapRequest(NULL),
-    icapReply(NULL),
-    attempts(0),
-    connection(NULL),
-    theService(aService),
-    commBuf(NULL),
-    commBufSize(0),
-    commEof(false),
-    reuseConnection(true),
-    isRetriable(true),
-    isRepeatable(true),
-    ignoreLastWrite(false),
-    stopReason(NULL),
-    connector(NULL),
-    reader(NULL),
-    writer(NULL),
-    closer(NULL),
-    alep(new AccessLogEntry),
-    al(*alep),
-    cs(NULL)
+        AsyncJob(aTypeName),
+        Adaptation::Initiate(aTypeName),
+        icapRequest(NULL),
+        icapReply(NULL),
+        attempts(0),
+        connection(NULL),
+        theService(aService),
+        commBuf(NULL),
+        commBufSize(0),
+        commEof(false),
+        reuseConnection(true),
+        isRetriable(true),
+        isRepeatable(true),
+        ignoreLastWrite(false),
+        stopReason(NULL),
+        connector(NULL),
+        reader(NULL),
+        writer(NULL),
+        closer(NULL),
+        alep(new AccessLogEntry),
+        al(*alep),
+        cs(NULL)
 {
     debugs(93,3, typeName << " constructed, this=" << this <<
            " [icapx" << id << ']'); // we should not call virtual status() here
@@ -184,7 +184,7 @@ Adaptation::Icap::Xaction::dnsLookupDone(const ipcache_addrs *ia)
     connector = JobCallback(93,3, ConnectDialer, this, Adaptation::Icap::Xaction::noteCommConnected);
     cs = new Comm::ConnOpener(connection, connector, TheConfig.connect_timeout(service().cfg().bypass));
     cs->setHost(s.cfg().host.termedBuf());
-    AsyncJob::Start(cs.get());
+    AsyncJob::Start(cs);
 }
 
 /*
@@ -453,7 +453,7 @@ bool Adaptation::Icap::Xaction::parseHttpMsg(HttpMsg *msg)
     const bool parsed = msg->parse(&readBuf, commEof, &error);
     Must(parsed || !error); // success or need more data
 
-    if (!parsed) {  // need more data
+    if (!parsed) {	// need more data
         Must(mayReadMore());
         msg->reset();
         return false;
@@ -522,7 +522,7 @@ void Adaptation::Icap::Xaction::setOutcome(const Adaptation::Icap::XactOutcome &
 void Adaptation::Icap::Xaction::swanSong()
 {
     // kids should sing first and then call the parent method.
-    if (cs.valid()) {
+    if (cs) {
         debugs(93,6, HERE << id << " about to notify ConnOpener!");
         CallJobHere(93, 3, cs, Comm::ConnOpener, noteAbort);
         cs = NULL;
@@ -598,7 +598,9 @@ const char *Adaptation::Icap::Xaction::status() const
     fillPendingStatus(buf);
     buf.append("/", 1);
     fillDoneStatus(buf);
-    buf.Printf(" %s%u]", id.prefix(), id.value);
+
+    buf.Printf(" %s%u]", id.Prefix, id.value);
+
     buf.terminate();
 
     return buf.content();
@@ -632,4 +634,3 @@ bool Adaptation::Icap::Xaction::fillVirginHttpHeader(MemBuf &buf) const
 {
     return false;
 }
-
