@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-2017 The Squid Software Foundation and contributors
+ * Copyright (C) 1996-2014 The Squid Software Foundation and contributors
  *
  * Squid software is distributed under GPLv2+ license and includes
  * contributions from numerous individuals and organizations.
@@ -27,50 +27,48 @@ int NHttpSockets = 0;
 int HttpSockets[MAXTCPLISTENPORTS];
 
 AnyP::PortCfg::PortCfg() :
-    next(),
-    s(),
-    transport(AnyP::PROTO_HTTP,1,1), // "Squid is an HTTP proxy", etc.
-    name(NULL),
-    defaultsite(NULL),
-    flags(),
-    allow_direct(false),
-    vhost(false),
-    actAsOrigin(false),
-    ignore_cc(false),
-    connection_auth_disabled(false),
-    ftp_track_dirs(false),
-    vport(0),
-    disable_pmtu_discovery(0),
-    listenConn()
+        next(),
+        s(),
+        transport(AnyP::PROTO_HTTP,1,1), // "Squid is an HTTP proxy", etc.
+        name(NULL),
+        defaultsite(NULL),
+        flags(),
+        allow_direct(false),
+        vhost(false),
+        actAsOrigin(false),
+        ignore_cc(false),
+        connection_auth_disabled(false),
+        ftp_track_dirs(false),
+        vport(0),
+        disable_pmtu_discovery(0),
+        listenConn()
 #if USE_OPENSSL
-    ,cert(NULL),
-    key(NULL),
-    version(0),
-    cipher(NULL),
-    options(NULL),
-    clientca(NULL),
-    cafile(NULL),
-    capath(NULL),
-    crlfile(NULL),
-    dhfile(NULL),
-    tls_dh(NULL),
-    sslflags(NULL),
-    sslContextSessionId(NULL),
-    generateHostCertificates(false),
-    dynamicCertMemCacheSize(std::numeric_limits<size_t>::max()),
-    staticSslContext(),
-    signingCert(),
-    signPkey(),
-    certsToChain(),
-    untrustedSigningCert(),
-    untrustedSignPkey(),
-    clientVerifyCrls(),
-    clientCA(),
-    dhParams(),
-    eecdhCurve(NULL),
-    contextMethod(),
-    sslContextFlags(0),
-    sslOptions(0)
+        ,cert(NULL),
+        key(NULL),
+        version(0),
+        cipher(NULL),
+        options(NULL),
+        clientca(NULL),
+        cafile(NULL),
+        capath(NULL),
+        crlfile(NULL),
+        dhfile(NULL),
+        sslflags(NULL),
+        sslContextSessionId(NULL),
+        generateHostCertificates(false),
+        dynamicCertMemCacheSize(std::numeric_limits<size_t>::max()),
+        staticSslContext(),
+        signingCert(),
+        signPkey(),
+        certsToChain(),
+        untrustedSigningCert(),
+        untrustedSignPkey(),
+        clientVerifyCrls(),
+        clientCA(),
+        dhParams(),
+        contextMethod(),
+        sslContextFlags(0),
+        sslOptions(0)
 #endif
 {
     memset(&tcp_keepalive, 0, sizeof(tcp_keepalive));
@@ -96,10 +94,8 @@ AnyP::PortCfg::~PortCfg()
     safe_free(capath);
     safe_free(crlfile);
     safe_free(dhfile);
-    safe_free(tls_dh);
     safe_free(sslflags);
     safe_free(sslContextSessionId);
-    safe_free(eecdhCurve);
 #endif
 }
 
@@ -123,36 +119,22 @@ AnyP::PortCfg::clone() const
     b->disable_pmtu_discovery = disable_pmtu_discovery;
     b->tcp_keepalive = tcp_keepalive;
 
-#if USE_OPENSSL
-    if (cert)
-        b->cert = xstrdup(cert);
-    if (key)
-        b->key = xstrdup(key);
-    b->version = version;
-    if (cipher)
-        b->cipher = xstrdup(cipher);
-    if (options)
-        b->options = xstrdup(options);
-    if (clientca)
-        b->clientca = xstrdup(clientca);
-    if (cafile)
-        b->cafile = xstrdup(cafile);
-    if (capath)
-        b->capath = xstrdup(capath);
-    if (crlfile)
-        b->crlfile = xstrdup(crlfile);
-    if (dhfile)
-        b->dhfile = xstrdup(dhfile);
-    if (tls_dh)
-        b->tls_dh = xstrdup(tls_dh);
-    if (sslflags)
-        b->sslflags = xstrdup(sslflags);
-    if (sslContextSessionId)
-        b->sslContextSessionId = xstrdup(sslContextSessionId);
-
 #if 0
-    // TODO: AYJ: 2015-01-15: for now SSL does not clone the context object.
-    // cloning should only be done before the PortCfg is post-configure initialized and opened
+    // TODO: AYJ: 2009-07-18: for now SSL does not clone. Configure separate ports with IPs and SSL settings
+
+#if USE_OPENSSL
+    char *cert;
+    char *key;
+    int version;
+    char *cipher;
+    char *options;
+    char *clientca;
+    char *cafile;
+    char *capath;
+    char *crlfile;
+    char *dhfile;
+    char *sslflags;
+    char *sslContextSessionId;
     SSL_CTX *sslContext;
 #endif
 
@@ -198,23 +180,8 @@ AnyP::PortCfg::configureSslServerContext()
     if (!contextMethod)
         fatalf("Unable to compute context method to use");
 
-    const char *dhParamsFile = dhfile; // backward compatibility for dhparams= configuration
-    safe_free(eecdhCurve); // clear any previous EECDH configuration
-    if (tls_dh && *tls_dh) {
-        eecdhCurve = xstrdup(tls_dh);
-        char *p = strchr(eecdhCurve, ':');
-        if (p) {  // tls-dh=eecdhCurve:dhParamsFile
-            *p = '\0';
-            dhParamsFile = p+1;
-        } else {  // tls-dh=dhParamsFile
-            dhParamsFile = tls_dh;
-            // a NULL eecdhCurve means "do not use EECDH"
-            safe_free(eecdhCurve);
-        }
-    }
-
-    if (dhParamsFile && *dhParamsFile)
-        dhParams.reset(Ssl::readDHParams(dhParamsFile));
+    if (dhfile)
+        dhParams.reset(Ssl::readDHParams(dhfile));
 
     if (sslflags)
         sslContextFlags = Ssl::parse_flags(sslflags);
@@ -229,4 +196,3 @@ AnyP::PortCfg::configureSslServerContext()
     }
 }
 #endif
-
