@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-2017 The Squid Software Foundation and contributors
+ * Copyright (C) 1996-2014 The Squid Software Foundation and contributors
  *
  * Squid software is distributed under GPLv2+ license and includes
  * contributions from numerous individuals and organizations.
@@ -31,8 +31,8 @@ int clientBeginRequest(const HttpRequestMethod&, char const *, CSCB *, CSD *, Cl
 
 class ClientHttpRequest
 #if USE_ADAPTATION
-    : public Adaptation::Initiator, // to start adaptation transactions
-      public BodyConsumer     // to receive reply bodies in request satisf. mode
+        : public Adaptation::Initiator, // to start adaptation transactions
+        public BodyConsumer     // to receive reply bodies in request satisf. mode
 #endif
 {
 
@@ -66,19 +66,19 @@ public:
      */
     Comm::ConnectionPointer clientConnection;
 
-    HttpRequest *request;       /* Parsed URL ... */
+    HttpRequest *request;		/* Parsed URL ... */
     char *uri;
     char *log_uri;
     String store_id; /* StoreID for transactions where the request member is nil */
 
     struct {
         int64_t offset;
-        uint64_t size;
+        int64_t size;
         size_t headers_sz;
     } out;
 
-    HttpHdrRangeIter range_iter;    /* data for iterating thru range specs */
-    size_t req_sz;      /* raw request size on input, not current request size */
+    HttpHdrRangeIter range_iter;	/* data for iterating thru range specs */
+    size_t req_sz;		/* raw request size on input, not current request size */
 
     /// the processing tags associated with this request transaction.
     // NP: still an enum so each stage altering it must take care when replacing it.
@@ -113,7 +113,6 @@ public:
         return Initiator::doneAll() &&
                BodyConsumer::doneAll() && false;
     }
-    virtual void callException(const std::exception &ex);
 #endif
 
 private:
@@ -141,7 +140,6 @@ public:
 
 public:
     void startAdaptation(const Adaptation::ServiceGroupPointer &g);
-    bool requestSatisfactionMode() const { return request_satisfaction_mode; }
 
     // private but exposed for ClientRequestContext
     void handleAdaptationFailure(int errDetail, bool bypassable = false);
@@ -182,7 +180,7 @@ int clientHttpRequestStatus(int fd, ClientHttpRequest const *http);
 void clientAccessCheck(ClientHttpRequest *);
 
 /* ones that should be elsewhere */
-void tunnelStart(ClientHttpRequest *);
+void tunnelStart(ClientHttpRequest *, int64_t *, int *, const AccessLogEntry::Pointer &al);
 
 #if _USE_INLINE_
 #include "client_side_request.cci"
@@ -190,4 +188,3 @@ void tunnelStart(ClientHttpRequest *);
 #endif
 
 #endif /* SQUID_CLIENTSIDEREQUEST_H */
-
