@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-2017 The Squid Software Foundation and contributors
+ * Copyright (C) 1996-2014 The Squid Software Foundation and contributors
  *
  * Squid software is distributed under GPLv2+ license and includes
  * contributions from numerous individuals and organizations.
@@ -96,8 +96,7 @@ public:
     virtual ~Client();
 
     /// handle a fatal transaction error, closing the control connection
-    virtual void failed(err_type error = ERR_NONE, int xerrno = 0,
-                        ErrorState *ftperr = NULL);
+    virtual void failed(err_type error = ERR_NONE, int xerrno = 0);
 
     /// read timeout handler
     virtual void timeout(const CommTimeoutCbParams &io);
@@ -165,7 +164,7 @@ protected:
     virtual void closeServer();
     virtual bool doneWithServer() const;
     virtual const Comm::ConnectionPointer & dataConnection() const;
-    virtual void abortAll(const char *reason);
+    virtual void abortTransaction(const char *reason);
 
     virtual Http::StatusCode failedHttpStatus(err_type &error);
     void ctrlClosed(const CommCloseCbParams &io);
@@ -197,4 +196,3 @@ private:
 } // namespace Ftp
 
 #endif /* SQUID_FTP_CLIENT_H */
-
