@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-2017 The Squid Software Foundation and contributors
+ * Copyright (C) 1996-2014 The Squid Software Foundation and contributors
  *
  * Squid software is distributed under GPLv2+ license and includes
  * contributions from numerous individuals and organizations.
@@ -48,8 +48,8 @@ ESICustomParser::GetTrie()
 }
 
 ESICustomParser::ESICustomParser(ESIParserClient *aClient) :
-    theClient(aClient),
-    lastTag(ESITAG)
+        theClient(aClient),
+        lastTag(ESITAG)
 {}
 
 ESICustomParser::~ESICustomParser()
@@ -89,11 +89,9 @@ ESICustomParser::parse(char const *dataToParse, size_t const lengthOfData, bool
     }
 
     size_t openESITags (0);
-    // TODO: convert to Tokenizer parse
-    // erring on the safe side for now. Probably rawContent would be ok too
-    // note that operations below do *X='\0' ... altering the 'const' buffer content.
-    char const *currentPos = content.c_str();
-    SBuf::size_type remainingCount = content.length();
+    //erring on the safe side. Probably rawBuf would be ok too
+    char const *currentPos = content.termedBuf();
+    size_t remainingCount = content.size();
     char const *tag = NULL;
 
     while ((tag = findTag(currentPos, remainingCount))) {
@@ -297,4 +295,3 @@ ESICustomParser::errorString() const
     else
         return "Parsing error strings not implemented";
 }
-
