@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-2015 The Squid Software Foundation and contributors
+ * Copyright (C) 1996-2014 The Squid Software Foundation and contributors
  *
  * Squid software is distributed under GPLv2+ license and includes
  * contributions from numerous individuals and organizations.
@@ -311,6 +311,8 @@ ESIContext::fixupOutboundTail()
 esiKick_t
 ESIContext::kick ()
 {
+    assert (this);
+
     if (flags.kicked) {
         debugs(86, 5, "esiKick: Re-entered whilst in progress");
         // return ESI_KICK_INPROGRESS;
@@ -409,9 +411,9 @@ esiStreamRead (clientStreamNode *thisNode, ClientHttpRequest *http)
     switch (context->kick ()) {
 
     case ESIContext::ESI_KICK_FAILED:
-    /* this can not happen - processing can't fail until we have data,
-     * and when we come here we have sent data to the client
-     */
+        /* this can not happen - processing can't fail until we have data,
+         * and when we come here we have sent data to the client
+         */
 
     case ESIContext::ESI_KICK_SENT:
 
@@ -928,9 +930,9 @@ ESIContext::ParserState::top()
 }
 
 ESIContext::ParserState::ParserState() :
-    stackdepth(0),
-    parsing(0),
-    inited_(false)
+        stackdepth(0),
+        parsing(0),
+        inited_(false)
 {}
 
 bool
@@ -1572,7 +1574,7 @@ esiLiteral::process (int dovars)
 }
 
 esiLiteral::esiLiteral(esiLiteral const &old) : buffer (old.buffer->cloneList()),
-    varState (NULL)
+        varState (NULL)
 {
     flags.donevars = 0;
 }
@@ -1669,8 +1671,8 @@ esiTry::~esiTry()
 }
 
 esiTry::esiTry(esiTreeParentPtr aParent) :
-    parent(aParent),
-    exceptbuffer(NULL)
+        parent(aParent),
+        exceptbuffer(NULL)
 {
     memset(&flags, 0, sizeof(flags));
 }
@@ -1679,6 +1681,7 @@ void
 esiTry::render(ESISegment::Pointer output)
 {
     /* Try renders from it's children */
+    assert (this);
     assert (attempt.getRaw());
     assert (except.getRaw());
     debugs(86, 5, "esiTryRender: Rendering Try " << this);
@@ -1746,6 +1749,7 @@ esiProcessResult_t
 esiTry::process (int dovars)
 {
     esiProcessResult_t rv = ESI_PROCESS_PENDING_MAYFAIL;
+    assert (this);
 
     if (!attempt.getRaw()) {
         debugs(86, DBG_CRITICAL, "esiTryProcess: Try has no attempt element - ESI template is invalid (section 3.4)");
@@ -2292,10 +2296,10 @@ ElementList::size() const
 
 /* esiWhen */
 esiWhen::esiWhen(esiTreeParentPtr aParent, int attrcount, const char **attr,ESIVarState *aVar) :
-    esiSequence(aParent),
-    testValue(false),
-    unevaluatedExpression(NULL),
-    varState(NULL)
+        esiSequence(aParent),
+        testValue(false),
+        unevaluatedExpression(NULL),
+        varState(NULL)
 {
     char const *expression = NULL;
 
@@ -2351,10 +2355,10 @@ esiWhen::evaluate()
 }
 
 esiWhen::esiWhen(esiWhen const &old) :
-    esiSequence(old),
-    testValue(false),
-    unevaluatedExpression(NULL),
-    varState(NULL)
+        esiSequence(old),
+        testValue(false),
+        unevaluatedExpression(NULL),
+        varState(NULL)
 {
     if (old.unevaluatedExpression)
         unevaluatedExpression = xstrdup(old.unevaluatedExpression);
@@ -2408,12 +2412,14 @@ esiEnableProcessing (HttpReply *rep)
         HttpHdrScTarget *sctusable =
             rep->surrogate_control->getMergedTarget(Config.Accel.surrogate_id);
 
-        // found something targeted at us
-        if (sctusable &&
-                sctusable->hasContent() &&
-                sctusable->content().pos("ESI/1.0")) {
+        if (!sctusable || !sctusable->hasContent())
+            /* Nothing generic or targeted at us, or no
+             * content processing requested
+             */
+            return 0;
+
+        if (sctusable->content().pos("ESI/1.0") != NULL)
             rv = 1;
-        }
 
         delete sctusable;
     }
@@ -2422,4 +2428,3 @@ esiEnableProcessing (HttpReply *rep)
 }
 
 #endif /* USE_SQUID_ESI == 1 */
-
