@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-2017 The Squid Software Foundation and contributors
+ * Copyright (C) 1996-2014 The Squid Software Foundation and contributors
  *
  * Squid software is distributed under GPLv2+ license and includes
  * contributions from numerous individuals and organizations.
@@ -198,6 +198,7 @@ esiBufferRecipient (clientStreamNode *node, ClientHttpRequest *http, HttpReply *
 /* esiStream functions */
 ESIStreamContext::~ESIStreamContext()
 {
+    assert (this);
     freeResources();
 }
 
@@ -259,12 +260,12 @@ ESIInclude::makeUsable(esiTreeParentPtr newParent, ESIVarState &newVarState) con
 }
 
 ESIInclude::ESIInclude(ESIInclude const &old) :
-    varState(NULL),
-    srcurl(NULL),
-    alturl(NULL),
-    parent(NULL),
-    started(false),
-    sent(false)
+        varState(NULL),
+        srcurl(NULL),
+        alturl(NULL),
+        parent(NULL),
+        started(false),
+        sent(false)
 {
     memset(&flags, 0, sizeof(flags));
     flags.onerrorcontinue = old.flags.onerrorcontinue;
@@ -279,7 +280,7 @@ ESIInclude::ESIInclude(ESIInclude const &old) :
 void
 ESIInclude::prepareRequestHeaders(HttpHeader &tempheaders, ESIVarState *vars)
 {
-    tempheaders.update (&vars->header());
+    tempheaders.update (&vars->header(), NULL);
     tempheaders.removeHopByHopEntries();
 }
 
@@ -309,12 +310,12 @@ ESIInclude::Start (ESIStreamContext::Pointer stream, char const *url, ESIVarStat
 }
 
 ESIInclude::ESIInclude(esiTreeParentPtr aParent, int attrcount, char const **attr, ESIContext *aContext) :
-    varState(NULL),
-    srcurl(NULL),
-    alturl(NULL),
-    parent(aParent),
-    started(false),
-    sent(false)
+        varState(NULL),
+        srcurl(NULL),
+        alturl(NULL),
+        parent(aParent),
+        started(false),
+        sent(false)
 {
     assert (aContext);
     memset(&flags, 0, sizeof(flags));
@@ -452,6 +453,8 @@ ESIInclude::dataNeeded() const
 void
 ESIInclude::subRequestDone (ESIStreamContext::Pointer stream, bool success)
 {
+    assert (this);
+
     if (!dataNeeded())
         return;
 
@@ -560,4 +563,3 @@ ESIInclude::subRequestDone (ESIStreamContext::Pointer stream, bool success)
 }
 
 #endif /* USE_SQUID_ESI == 1 */
-
