@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-2017 The Squid Software Foundation and contributors
+ * Copyright (C) 1996-2014 The Squid Software Foundation and contributors
  *
  * Squid software is distributed under GPLv2+ license and includes
  * contributions from numerous individuals and organizations.
@@ -31,7 +31,7 @@ Eui::Eui64::decode(const char *asc)
 }
 
 bool
-Eui::Eui64::encode(char *buf, const int len) const
+Eui::Eui64::encode(char *buf, const int len)
 {
     if (len < SZ_EUI64_BUF) return false;
 
@@ -93,4 +93,3 @@ Eui::Eui64::lookupNdp(const Ip::Address &c)
 }
 
 #endif /* USE_SQUID_EUI */
-
