@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-2017 The Squid Software Foundation and contributors
+ * Copyright (C) 1996-2014 The Squid Software Foundation and contributors
  *
  * Squid software is distributed under GPLv2+ license and includes
  * contributions from numerous individuals and organizations.
@@ -47,6 +47,8 @@ typedef struct _htcpDataHeaderSquid htcpDataHeaderSquid;
 
 typedef struct _htcpAuthHeader htcpAuthHeader;
 
+typedef struct _htcpStuff htcpStuff;
+
 typedef struct _htcpDetail htcpDetail;
 
 struct _Countstr {
@@ -137,17 +139,6 @@ class htcpSpecifier : public StoreClient
 public:
     MEMPROXY_CLASS(htcpSpecifier);
 
-    htcpSpecifier() :
-        method(NULL),
-        uri(NULL),
-        version(NULL),
-        req_hdrs(NULL),
-        request(NULL),
-        checkHitRequest(NULL),
-        dhdr(NULL)
-    {}
-    // XXX: destructor?
-
     void created (StoreEntry *newEntry);
     void checkHit();
     void checkedHit(StoreEntry *e);
@@ -175,20 +166,7 @@ struct _htcpDetail {
     char *cache_hdrs;
 };
 
-class htcpStuff
-{
-public:
-    htcpStuff(uint32_t id, int o, int r, int f) :
-        op(o),
-        rr(r),
-        f1(f),
-        response(0),
-        reason(0),
-        msg_id(id)
-    {
-        memset(&D, 0, sizeof(D));
-    }
-
+struct _htcpStuff {
     int op;
     int rr;
     int f1;
@@ -444,9 +422,9 @@ htcpBuildTstOpData(char *buf, size_t buflen, htcpStuff * stuff)
         debugs(31, 3, "htcpBuildTstOpData: RR_RESPONSE");
         debugs(31, 3, "htcpBuildTstOpData: F1 = " << stuff->f1);
 
-        if (stuff->f1)      /* cache miss */
+        if (stuff->f1)		/* cache miss */
             return 0;
-        else            /* cache hit */
+        else			/* cache hit */
             return htcpBuildDetail(buf, buflen, stuff);
 
     default:
@@ -511,7 +489,7 @@ htcpBuildData(char *buf, size_t buflen, htcpStuff * stuff)
     if (buflen < hdr_sz)
         return -1;
 
-    off += hdr_sz;      /* skip! */
+    off += hdr_sz;		/* skip! */
 
     op_data_sz = htcpBuildOpData(buf + off, buflen - off, stuff);
 
@@ -856,15 +834,19 @@ htcpAccessAllowed(acl_access * acl, htcpSpecifier * s, Ip::Address &from)
 static void
 htcpTstReply(htcpDataHeader * dhdr, StoreEntry * e, htcpSpecifier * spec, Ip::Address &from)
 {
+    htcpStuff stuff;
     static char pkt[8192];
     HttpHeader hdr(hoHtcpReply);
     MemBuf mb;
     Packer p;
     ssize_t pktlen;
-
-    htcpStuff stuff(dhdr->msg_id, HTCP_TST, RR_RESPONSE, 0);
+    memset(&stuff, '\0', sizeof(stuff));
+    stuff.op = HTCP_TST;
+    stuff.rr = RR_RESPONSE;
+    stuff.f1 = 0;
     stuff.response = e ? 0 : 1;
     debugs(31, 3, "htcpTstReply: response = " << stuff.response);
+    stuff.msg_id = dhdr->msg_id;
 
     if (spec) {
         mb.init();
@@ -886,8 +868,8 @@ htcpTstReply(htcpDataHeader * dhdr, StoreEntry * e, htcpSpecifier * spec, Ip::Ad
         if (e && e->expires > -1)
             hdr.putTime(HDR_EXPIRES, e->expires);
 
-        if (e && e->lastModified() > -1)
-            hdr.putTime(HDR_LAST_MODIFIED, e->lastModified());
+        if (e && e->lastmod > -1)
+            hdr.putTime(HDR_LAST_MODIFIED, e->lastmod);
 
         hdr.packInto(&p);
 
@@ -941,6 +923,7 @@ static void
 
 htcpClrReply(htcpDataHeader * dhdr, int purgeSucceeded, Ip::Address &from)
 {
+    htcpStuff stuff;
     static char pkt[8192];
     ssize_t pktlen;
 
@@ -949,12 +932,20 @@ htcpClrReply(htcpDataHeader * dhdr, int purgeSucceeded, Ip::Address &from)
     if (dhdr->F1 == 0)
         return;
 
-    htcpStuff stuff(dhdr->msg_id, HTCP_CLR, RR_RESPONSE, 0);
+    memset(&stuff, '\0', sizeof(stuff));
+
+    stuff.op = HTCP_CLR;
+
+    stuff.rr = RR_RESPONSE;
+
+    stuff.f1 = 0;
 
     stuff.response = purgeSucceeded ? 0 : 2;
 
     debugs(31, 3, "htcpClrReply: response = " << stuff.response);
 
+    stuff.msg_id = dhdr->msg_id;
+
     pktlen = htcpBuildPacket(pkt, sizeof(pkt), &stuff);
 
     if (pktlen == 0) {
@@ -1075,7 +1066,7 @@ htcpHandleTst(htcpDataHeader * hdr, char *buf, int sz, Ip::Address &from)
 }
 
 HtcpReplyData::HtcpReplyData() :
-    hit(0), hdr(hoHtcpReply), msg_id(0), version(0.0)
+        hit(0), hdr(hoHtcpReply), msg_id(0), version(0.0)
 {
     memset(&cto, 0, sizeof(cto));
 }
@@ -1201,10 +1192,10 @@ void
 htcpSpecifier::checkedHit(StoreEntry *e)
 {
     if (e) {
-        htcpTstReply(dhdr, e, this, from);      /* hit */
+        htcpTstReply(dhdr, e, this, from);		/* hit */
         htcpLogHtcp(from, dhdr->opcode, LOG_UDP_HIT, uri);
     } else {
-        htcpTstReply(dhdr, NULL, NULL, from);   /* cache miss */
+        htcpTstReply(dhdr, NULL, NULL, from);	/* cache miss */
         htcpLogHtcp(from, dhdr->opcode, LOG_UDP_MISS, uri);
     }
 
@@ -1275,12 +1266,12 @@ htcpHandleClr(htcpDataHeader * hdr, char *buf, int sz, Ip::Address &from)
     switch (htcpClrStore(s)) {
 
     case 1:
-        htcpClrReply(hdr, 1, from); /* hit */
+        htcpClrReply(hdr, 1, from);	/* hit */
         htcpLogHtcp(from, hdr->opcode, LOG_UDP_HIT, s->uri);
         break;
 
     case 0:
-        htcpClrReply(hdr, 0, from); /* miss */
+        htcpClrReply(hdr, 0, from);	/* miss */
         htcpLogHtcp(from, hdr->opcode, LOG_UDP_MISS, s->uri);
         break;
 
@@ -1547,6 +1538,7 @@ htcpQuery(StoreEntry * e, HttpRequest * req, CachePeer * p)
     static char pkt[8192];
     ssize_t pktlen;
     char vbuf[32];
+    htcpStuff stuff;
     HttpHeader hdr(hoRequest);
     Packer pa;
     MemBuf mb;
@@ -1559,8 +1551,11 @@ htcpQuery(StoreEntry * e, HttpRequest * req, CachePeer * p)
     memset(&flags, '\0', sizeof(flags));
     snprintf(vbuf, sizeof(vbuf), "%d/%d",
              req->http_ver.major, req->http_ver.minor);
-
-    htcpStuff stuff(++msg_id_counter, HTCP_TST, RR_REQUEST, 1);
+    stuff.op = HTCP_TST;
+    stuff.rr = RR_REQUEST;
+    stuff.f1 = 1;
+    stuff.response = 0;
+    stuff.msg_id = ++msg_id_counter;
     SBuf sb = req->method.image();
     stuff.S.method = sb.c_str();
     stuff.S.uri = (char *) e->url();
@@ -1599,6 +1594,7 @@ htcpClear(StoreEntry * e, const char *uri, HttpRequest * req, const HttpRequestM
     static char pkt[8192];
     ssize_t pktlen;
     char vbuf[32];
+    htcpStuff stuff;
     HttpHeader hdr(hoRequest);
     Packer pa;
     MemBuf mb;
@@ -1611,11 +1607,19 @@ htcpClear(StoreEntry * e, const char *uri, HttpRequest * req, const HttpRequestM
     memset(&flags, '\0', sizeof(flags));
     snprintf(vbuf, sizeof(vbuf), "%d/%d",
              req->http_ver.major, req->http_ver.minor);
-
-    htcpStuff stuff(++msg_id_counter, HTCP_CLR, RR_REQUEST, 0);
-    if (reason == HTCP_CLR_INVALIDATION)
+    stuff.op = HTCP_CLR;
+    stuff.rr = RR_REQUEST;
+    stuff.f1 = 0;
+    stuff.response = 0;
+    stuff.msg_id = ++msg_id_counter;
+    switch (reason) {
+    case HTCP_CLR_INVALIDATION:
         stuff.reason = 1;
-
+        break;
+    default:
+        stuff.reason = 0;
+        break;
+    }
     SBuf sb = req->method.image();
     stuff.S.method = sb.c_str();
     if (e == NULL || e->mem_obj == NULL) {
@@ -1712,4 +1716,3 @@ htcpLogHtcp(Ip::Address &caddr, int opcode, LogTags logcode, const char *url)
     al->cache.msec = 0;
     accessLogLog(al, NULL);
 }
-
