@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-2017 The Squid Software Foundation and contributors
+ * Copyright (C) 1996-2014 The Squid Software Foundation and contributors
  *
  * Squid software is distributed under GPLv2+ license and includes
  * contributions from numerous individuals and organizations.
@@ -34,12 +34,9 @@ public:
     void clean();
 
     /// set this status-line to the given values
-    /// when reason is not NULL, it must not point to a dynamically allocated value
+    /// when reason is NULL the default message text for this StatusCode will be used
     void set(const Http::ProtocolVersion &newVersion, Http::StatusCode newStatus, const char *newReason = NULL);
 
-    /// reset the reason phrase to its default status code-derived value
-    void resetReason() { reason_ = NULL; }
-
     /// retrieve the status code for this status line
     Http::StatusCode status() const { return status_; }
 
@@ -79,4 +76,3 @@ private:
 } // namespace Http
 
 #endif /* SQUID_HTTP_STATUSLINE_H */
-
