@@ -1,20 +1,24 @@
 /*
- * $Id$
- *
- * DEBUG: section 54    Interprocess Communication
+ * Copyright (C) 1996-2014 The Squid Software Foundation and contributors
  *
+ * Squid software is distributed under GPLv2+ license and includes
+ * contributions from numerous individuals and organizations.
+ * Please see the COPYING and CONTRIBUTORS files for details.
  */
 
+/* DEBUG: section 54    Interprocess Communication */
 
-#include "config.h"
+#include "squid.h"
 #include "comm.h"
-#include "CommCalls.h"
 #include "comm/Connection.h"
+#include "comm/Read.h"
+#include "CommCalls.h"
 #include "ipc/Port.h"
+#include "tools.h"
 
-const char Ipc::coordinatorAddr[] = DEFAULT_STATEDIR "/coordinator.ipc";
-const char Ipc::strandAddrPfx[] = DEFAULT_STATEDIR "/kid";
-
+static const char channelPathPfx[] = DEFAULT_STATEDIR "/";
+static const char coordinatorAddrLabel[] = "-coordinator";
+const char Ipc::strandAddrLabel[] =  "-kid";
 
 Ipc::Port::Port(const String& aListenAddr):
         UdsOp(aListenAddr)
@@ -25,10 +29,10 @@ Ipc::Port::Port(const String& aListenAddr):
 void Ipc::Port::start()
 {
     UdsOp::start();
-    listen();
+    doListen();
 }
 
-void Ipc::Port::listen()
+void Ipc::Port::doListen()
 {
     debugs(54, 6, HERE);
     buf.prepForReading();
@@ -43,26 +47,41 @@ bool Ipc::Port::doneAll() const
     return false; // listen forever
 }
 
-String Ipc::Port::MakeAddr(const char* pathAddr, int id)
+String Ipc::Port::MakeAddr(const char* processLabel, int id)
 {
     assert(id >= 0);
-    String addr = pathAddr;
+    String addr = channelPathPfx;
+    addr.append(service_name.c_str());
+    addr.append(processLabel);
     addr.append('-');
     addr.append(xitoa(id));
     addr.append(".ipc");
     return addr;
 }
 
+String
+Ipc::Port::CoordinatorAddr()
+{
+    static String coordinatorAddr;
+    if (!coordinatorAddr.size()) {
+        coordinatorAddr= channelPathPfx;
+        coordinatorAddr.append(service_name.c_str());
+        coordinatorAddr.append(coordinatorAddrLabel);
+        coordinatorAddr.append(".ipc");
+    }
+    return coordinatorAddr;
+}
+
 void Ipc::Port::noteRead(const CommIoCbParams& params)
 {
     debugs(54, 6, HERE << params.conn << " flag " << params.flag <<
            " [" << this << ']');
-    if (params.flag == COMM_OK) {
+    if (params.flag == Comm::OK) {
         assert(params.buf == buf.raw());
         receive(buf);
     }
     // TODO: if there was a fatal error on our socket, close the socket before
     // trying to listen again and print a level-1 error message.
 
-    listen();
+    doListen();
 }
