@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-2017 The Squid Software Foundation and contributors
+ * Copyright (C) 1996-2014 The Squid Software Foundation and contributors
  *
  * Squid software is distributed under GPLv2+ license and includes
  * contributions from numerous individuals and organizations.
@@ -40,8 +40,8 @@ Ipc::StoreMap::Init(const SBuf &path, const int sliceLimit)
 }
 
 Ipc::StoreMap::StoreMap(const SBuf &aPath): cleaner(NULL), path(aPath),
-    anchors(shm_old(Anchors)(StoreMapAnchorsId(path).c_str())),
-    slices(shm_old(Slices)(StoreMapSlicesId(path).c_str()))
+        anchors(shm_old(Anchors)(StoreMapAnchorsId(path).c_str())),
+        slices(shm_old(Slices)(StoreMapSlicesId(path).c_str()))
 {
     debugs(54, 5, "attached " << path << " with " <<
            anchors->capacity << '+' << slices->capacity);
@@ -491,7 +491,7 @@ Ipc::StoreMapAnchor::set(const StoreEntry &from)
     basics.timestamp = from.timestamp;
     basics.lastref = from.lastref;
     basics.expires = from.expires;
-    basics.lastmod = from.lastModified();
+    basics.lastmod = from.lastmod;
     basics.swap_file_sz = from.swap_file_sz;
     basics.refcount = from.refcount;
     basics.flags = from.flags;
@@ -520,10 +520,10 @@ Ipc::StoreMap::Owner::~Owner()
 /* Ipc::StoreMapAnchors */
 
 Ipc::StoreMapAnchors::StoreMapAnchors(const int aCapacity):
-    count(0),
-    victim(0),
-    capacity(aCapacity),
-    items(aCapacity)
+        count(0),
+        victim(0),
+        capacity(aCapacity),
+        items(aCapacity)
 {
 }
 
