@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-2017 The Squid Software Foundation and contributors
+ * Copyright (C) 1996-2014 The Squid Software Foundation and contributors
  *
  * Squid software is distributed under GPLv2+ license and includes
  * contributions from numerous individuals and organizations.
@@ -13,6 +13,28 @@
 #if HAVE_CTYPE_H
 #include <ctype.h>
 #endif
+#if HAVE_STDINT_H
+#include <stdint.h>
+#endif
+#ifndef INT64_MIN
+/* Native 64 bit system without strtoll() */
+#if defined(LONG_MIN) && (SIZEOF_LONG == 8)
+#define INT64_MIN LONG_MIN
+#else
+/* 32 bit system */
+#define INT64_MIN       (-9223372036854775807LL-1LL)
+#endif
+#endif
+
+#ifndef INT64_MAX
+/* Native 64 bit system without strtoll() */
+#if defined(LONG_MAX) && (SIZEOF_LONG == 8)
+#define INT64_MAX LONG_MAX
+#else
+/* 32 bit system */
+#define INT64_MAX       9223372036854775807LL
+#endif
+#endif
 
 /// convenience method: consumes up to n bytes, counts, and returns them
 SBuf
@@ -49,13 +71,11 @@ Parser::Tokenizer::token(SBuf &returnedToken, const CharacterSet &delimiters)
 bool
 Parser::Tokenizer::prefix(SBuf &returnedToken, const CharacterSet &tokenChars, const SBuf::size_type limit)
 {
-    SBuf::size_type prefixLen = buf_.substr(0,limit).findFirstNotOf(tokenChars);
+    const SBuf::size_type prefixLen = buf_.substr(0,limit).findFirstNotOf(tokenChars);
     if (prefixLen == 0)
         return false;
     if (prefixLen == SBuf::npos && (atEnd() || limit == 0))
         return false;
-    if (prefixLen == SBuf::npos && limit > 0)
-        prefixLen = limit;
     returnedToken = consume(prefixLen); // cannot be empty after the npos check
     return true;
 }
@@ -111,9 +131,8 @@ Parser::Tokenizer::int64(int64_t & result, int base)
     } else if (*s == '+') {
         ++s;
     }
-
     if (s >= end) return false;
-    if (( base == 0 || base == 16) && *s == '0' && (s+1 < end ) &&
+    if (( base == 0 || base == 16) && *s == '0' && (s+1 <= end ) &&
             tolower(*(s+1)) == 'x') {
         s += 2;
         base = 16;
@@ -136,8 +155,7 @@ Parser::Tokenizer::int64(int64_t & result, int base)
 
     int any = 0, c;
     int64_t acc = 0;
-    do {
-        c = *s;
+    for (c = *s++; s <= end; c = *s++) {
         if (xisdigit(c)) {
             c -= '0';
         } else if (xisalpha(c)) {
@@ -154,7 +172,7 @@ Parser::Tokenizer::int64(int64_t & result, int base)
             acc *= base;
             acc += c;
         }
-    } while (++s < end);
+    }
 
     if (any == 0) // nothing was parsed
         return false;
@@ -166,6 +184,5 @@ Parser::Tokenizer::int64(int64_t & result, int base)
         acc = -acc;
 
     result = acc;
-    return success(s - buf_.rawContent());
+    return success(s - buf_.rawContent() - 1);
 }
-
