@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-2017 The Squid Software Foundation and contributors
+ * Copyright (C) 1996-2014 The Squid Software Foundation and contributors
  *
  * Squid software is distributed under GPLv2+ license and includes
  * contributions from numerous individuals and organizations.
@@ -65,9 +65,9 @@ static Format::Format *storeIdExtrasFmt = NULL;
 CBDATA_CLASS_INIT(RedirectStateData);
 
 RedirectStateData::RedirectStateData(const char *url) :
-    data(NULL),
-    orig_url(url),
-    handler(NULL)
+        data(NULL),
+        orig_url(url),
+        handler(NULL)
 {
 }
 
@@ -369,13 +369,11 @@ redirectInit(void)
     }
 
     if (Config.redirector_extras) {
-        delete redirectorExtrasFmt;
         redirectorExtrasFmt = new ::Format::Format("url_rewrite_extras");
         (void)redirectorExtrasFmt->parse(Config.redirector_extras);
     }
 
     if (Config.storeId_extras) {
-        delete storeIdExtrasFmt;
         storeIdExtrasFmt = new ::Format::Format("store_id_extras");
         (void)storeIdExtrasFmt->parse(Config.storeId_extras);
     }
@@ -390,6 +388,9 @@ redirectShutdown(void)
      * When and if needed for more helpers a separated shutdown
      * method will be added for each of them.
      */
+    if (!storeIds && !redirectors)
+        return;
+
     if (redirectors)
         helperShutdown(redirectors);
 
@@ -411,4 +412,3 @@ redirectShutdown(void)
     delete storeIdExtrasFmt;
     storeIdExtrasFmt = NULL;
 }
-
