@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-2017 The Squid Software Foundation and contributors
+ * Copyright (C) 1996-2014 The Squid Software Foundation and contributors
  *
  * Squid software is distributed under GPLv2+ license and includes
  * contributions from numerous individuals and organizations.
@@ -25,11 +25,11 @@
 #define HERE "(ssl_crtd) " << __FILE__ << ':' << __LINE__ << ": "
 
 Ssl::Lock::Lock(std::string const &aFilename) :
-    filename(aFilename),
+        filename(aFilename),
 #if _SQUID_WINDOWS_
-    hFile(INVALID_HANDLE_VALUE)
+        hFile(INVALID_HANDLE_VALUE)
 #else
-    fd(-1)
+        fd(-1)
 #endif
 {
 }
@@ -50,15 +50,13 @@ void Ssl::Lock::lock()
     hFile = CreateFile(TEXT(filename.c_str()), GENERIC_READ, 0, NULL, OPEN_EXISTING, FILE_ATTRIBUTE_NORMAL, NULL);
     if (hFile == INVALID_HANDLE_VALUE)
 #else
-    fd = open(filename.c_str(), O_RDWR);
+    fd = open(filename.c_str(), 0);
     if (fd == -1)
 #endif
         throw std::runtime_error("Failed to open file " + filename);
 
 #if _SQUID_WINDOWS_
     if (!LockFile(hFile, 0, 0, 1, 0))
-#elif _SQUID_SOLARIS_
-    if (lockf(fd, F_LOCK, 0) != 0)
 #else
     if (flock(fd, LOCK_EX) != 0)
 #endif
@@ -75,11 +73,7 @@ void Ssl::Lock::unlock()
     }
 #else
     if (fd != -1) {
-#if _SQUID_SOLARIS_
-        lockf(fd, F_ULOCK, 0);
-#else
         flock(fd, LOCK_UN);
-#endif
         close(fd);
         fd = -1;
     }
@@ -95,7 +89,7 @@ Ssl::Lock::~Lock()
 }
 
 Ssl::Locker::Locker(Lock &aLock, const char *aFileName, int aLineNo):
-    weLocked(false), lock(aLock), fileName(aFileName), lineNo(aLineNo)
+        weLocked(false), lock(aLock), fileName(aFileName), lineNo(aLineNo)
 {
     if (!lock.locked()) {
         lock.lock();
@@ -110,7 +104,7 @@ Ssl::Locker::~Locker()
 }
 
 Ssl::CertificateDb::Row::Row()
-    :   width(cnlNumber)
+        :   width(cnlNumber)
 {
     row = (char **)OPENSSL_malloc(sizeof(char *) * (width + 1));
     for (size_t i = 0; i < width + 1; ++i)
@@ -206,7 +200,7 @@ void Ssl::CertificateDb::sq_TXT_DB_delete_row(TXT_DB *db, int idx) {
 
     Row row(rrow, cnlNumber); // row wrapper used to free the rrow
 
-    const Columns db_indexes[]= {cnlSerial, cnlName};
+    const Columns db_indexes[]={cnlSerial, cnlName};
     for (unsigned int i = 0; i < countof(db_indexes); ++i) {
         void *data = NULL;
 #if SQUID_SSLTXTDB_PSTRINGDATA
@@ -248,15 +242,15 @@ const std::string Ssl::CertificateDb::cert_dir("certs");
 const std::string Ssl::CertificateDb::size_file("size");
 
 Ssl::CertificateDb::CertificateDb(std::string const & aDb_path, size_t aMax_db_size, size_t aFs_block_size)
-    :  db_path(aDb_path),
-       db_full(aDb_path + "/" + db_file),
-       cert_full(aDb_path + "/" + cert_dir),
-       size_full(aDb_path + "/" + size_file),
-       db(NULL),
-       max_db_size(aMax_db_size),
-       fs_block_size((aFs_block_size ? aFs_block_size : 2048)),
-       dbLock(db_full),
-       enabled_disk_store(true) {
+        :  db_path(aDb_path),
+        db_full(aDb_path + "/" + db_file),
+        cert_full(aDb_path + "/" + cert_dir),
+        size_full(aDb_path + "/" + size_file),
+        db(NULL),
+        max_db_size(aMax_db_size),
+        fs_block_size((aFs_block_size ? aFs_block_size : 2048)),
+        dbLock(db_full),
+        enabled_disk_store(true) {
     if (db_path.empty() && !max_db_size)
         enabled_disk_store = false;
     else if ((db_path.empty() && max_db_size) || (!db_path.empty() && !max_db_size))
@@ -320,25 +314,18 @@ bool Ssl::CertificateDb::addCertAndPrivateKey(Ssl::X509_Pointer & cert, Ssl::EVP
     }
 
     // check db size while trying to minimize calls to size()
-    size_t dbSize = size();
-    if ((dbSize == 0 && hasRows()) ||
-            (dbSize > 0 && !hasRows()) ||
-            (dbSize >  10 * max_db_size)) {
-        // Invalid database size, rebuild
-        dbSize = rebuildSize();
-    }
-    while (dbSize > max_db_size && deleteInvalidCertificate()) {
-        dbSize = size(); // get the current database size
-        // and try to find another invalid certificate if needed
-    }
-    // there are no more invalid ones, but there must be valid certificates
-    while (dbSize > max_db_size) {
-        if (!deleteOldestCertificate()) {
-            rebuildSize(); // No certificates in database.Update the size file.
-            save(); // Some entries may have been removed. Update the index file.
-            return false; // errors prevented us from freeing enough space
-        }
-        dbSize = size(); // get the current database size
+    while (size() > max_db_size) {
+        if (deleteInvalidCertificate())
+            continue; // try to find another invalid certificate if needed
+
+        // there are no more invalid ones, but there must be valid certificates
+        do {
+            if (!deleteOldestCertificate()) {
+                save(); // Some entries may have been removed. Update the index file.
+                return false; // errors prevented us from freeing enough space
+            }
+        } while (size() > max_db_size);
+        break;
     }
 
     row.setValue(cnlType, "V");
@@ -421,7 +408,7 @@ size_t Ssl::CertificateDb::rebuildSize()
 #endif
         const std::string filename(cert_full + "/" + current_row[cnlSerial] + ".pem");
         const size_t fSize = getFileSize(filename);
-        dbSize += fSize;
+        dbSize += fSize;        
     }
     writeSize(dbSize);
     return dbSize;
@@ -463,8 +450,7 @@ void Ssl::CertificateDb::addSize(std::string const & filename) {
 void Ssl::CertificateDb::subSize(std::string const & filename) {
     // readSize will rebuild 'size' file if missing or it is corrupted
     size_t dbSize = readSize();
-    const size_t fileSize = getFileSize(filename);
-    dbSize = dbSize > fileSize ? dbSize - fileSize : 0;
+    dbSize -= getFileSize(filename);
     writeSize(dbSize);
 }
 
@@ -488,10 +474,8 @@ size_t Ssl::CertificateDb::getFileSize(std::string const & filename) {
     if (!file)
         return 0;
     file.seekg(0, std::ios_base::end);
-    const std::streampos file_size = file.tellg();
-    if (file_size < 0)
-        return 0;
-    return ((static_cast<size_t>(file_size) + fs_block_size - 1) / fs_block_size) * fs_block_size;
+    size_t file_size = file.tellg();
+    return ((file_size + fs_block_size - 1) / fs_block_size) * fs_block_size;
 }
 
 void Ssl::CertificateDb::load() {
@@ -571,9 +555,15 @@ bool Ssl::CertificateDb::deleteInvalidCertificate() {
     return true;
 }
 
-bool Ssl::CertificateDb::deleteOldestCertificate()
-{
-    if (!hasRows())
+bool Ssl::CertificateDb::deleteOldestCertificate() {
+    if (!db)
+        return false;
+
+#if SQUID_SSLTXTDB_PSTRINGDATA
+    if (sk_OPENSSL_PSTRING_num(db.get()->data) == 0)
+#else
+    if (sk_num(db.get()->data) == 0)
+#endif
         return false;
 
 #if SQUID_SSLTXTDB_PSTRINGDATA
@@ -614,21 +604,6 @@ bool Ssl::CertificateDb::deleteByHostname(std::string const & host) {
     return false;
 }
 
-bool Ssl::CertificateDb::hasRows() const
-{
-    if (!db)
-        return false;
-
-#if SQUID_SSLTXTDB_PSTRINGDATA
-    if (sk_OPENSSL_PSTRING_num(db.get()->data) == 0)
-#else
-    if (sk_num(db.get()->data) == 0)
-#endif
-        return false;
-    return true;
-}
-
 bool Ssl::CertificateDb::IsEnabledDiskStore() const {
     return enabled_disk_store;
 }
-
