@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-2017 The Squid Software Foundation and contributors
+ * Copyright (C) 1996-2014 The Squid Software Foundation and contributors
  *
  * Squid software is distributed under GPLv2+ license and includes
  * contributions from numerous individuals and organizations.
@@ -24,8 +24,8 @@
  \defgroup ssl_crtd ssl_crtd
  \ingroup ExternalPrograms
  \par
-    Because the standard generation of ssl certificate for
-    sslBump feature, Squid must use external process to
+    Because the standart generation of ssl certificate for
+    sslBump feature, Squid must use external proccess to
     actually make these calls. This process generate new ssl
     certificates and worked with ssl certificates disk cache.
     Typically there will be five ssl_crtd processes spawned
@@ -188,8 +188,11 @@ static void usage()
     std::cerr << help_string << std::endl;
 }
 
-/// Process new request message.
-static bool processNewRequest(Ssl::CrtdMessage & request_message, std::string const & db_path, size_t max_db_size, size_t fs_block_size)
+/**
+ \ingroup ssl_crtd
+ * Proccess new request message.
+ */
+static bool proccessNewRequest(Ssl::CrtdMessage & request_message, std::string const & db_path, size_t max_db_size, size_t fs_block_size)
 {
     Ssl::CertificateProperties certProperties;
     std::string error;
@@ -202,13 +205,7 @@ static bool processNewRequest(Ssl::CrtdMessage & request_message, std::string co
     Ssl::EVP_PKEY_Pointer pkey;
     std::string &cert_subject = certProperties.dbKey();
 
-    bool dbFailed = false;
-    try {
-        db.find(cert_subject, cert, pkey);
-    } catch (std::runtime_error &err) {
-        dbFailed = true;
-        error = err.what();
-    }
+    db.find(cert_subject, cert, pkey);
 
     if (cert.get()) {
         if (!Ssl::certificateMatchesProperties(cert.get(), certProperties)) {
@@ -224,22 +221,10 @@ static bool processNewRequest(Ssl::CrtdMessage & request_message, std::string co
         if (!Ssl::generateSslCertificate(cert, pkey, certProperties))
             throw std::runtime_error("Cannot create ssl certificate or private key.");
 
-        if (!dbFailed && db.IsEnabledDiskStore()) {
-            try {
-                if (!db.addCertAndPrivateKey(cert, pkey, cert_subject)) {
-                    dbFailed = true;
-                    error = "Cannot add certificate to db.";
-                }
-            } catch (const std::runtime_error &err) {
-                dbFailed = true;
-                error = err.what();
-            }
-        }
+        if (!db.addCertAndPrivateKey(cert, pkey, cert_subject) && db.IsEnabledDiskStore())
+            throw std::runtime_error("Cannot add certificate to db.");
     }
 
-    if (dbFailed)
-        std::cerr << "ssl_crtd helper database '" << db_path  << "' failed: " << error << std::endl;
-
     std::string bufferToWrite;
     if (!Ssl::writeCertAndPrivateKeyToMemory(cert, pkey, bufferToWrite))
         throw std::runtime_error("Cannot write ssl certificate or/and private key to memory.");
@@ -262,11 +247,11 @@ int main(int argc, char *argv[])
 {
     try {
         size_t max_db_size = 0;
-        size_t fs_block_size = 0;
+        size_t fs_block_size = 2048;
         int8_t c;
         bool create_new_db = false;
         std::string db_path;
-        // process options.
+        // proccess options.
         while ((c = getopt(argc, argv, "dcghvs:M:b:n:")) != -1) {
             switch (c) {
             case 'd':
@@ -307,26 +292,13 @@ int main(int argc, char *argv[])
             exit(0);
         }
 
-        if (fs_block_size == 0) {
-            struct statvfs sfs;
-
-            if (xstatvfs(db_path.c_str(), &sfs)) {
-                fs_block_size = 2048;
-            } else {
-                fs_block_size = sfs.f_frsize;
-                // Sanity check; make sure we have a meaningful value.
-                if (fs_block_size < 512)
-                    fs_block_size = 2048;
-            }
-        }
-
         {
             Ssl::CertificateDb::check(db_path, max_db_size, fs_block_size);
         }
         // Initialize SSL subsystem
         SSL_load_error_strings();
         SSLeay_add_ssl_algorithms();
-        // process request.
+        // proccess request.
         for (;;) {
             char request[HELPER_INPUT_BUFFER];
             Ssl::CrtdMessage request_message(Ssl::CrtdMessage::REQUEST);
@@ -342,7 +314,7 @@ int main(int argc, char *argv[])
             if (parse_result == Ssl::CrtdMessage::ERROR) {
                 throw std::runtime_error("Cannot parse request message.");
             } else if (request_message.getCode() == Ssl::CrtdMessage::code_new_certificate) {
-                processNewRequest(request_message, db_path, max_db_size, fs_block_size);
+                proccessNewRequest(request_message, db_path, max_db_size, fs_block_size);
             } else {
                 throw std::runtime_error("Unknown request code: \"" + request_message.getCode() + "\".");
             }
@@ -350,8 +322,7 @@ int main(int argc, char *argv[])
         }
     } catch (std::runtime_error & error) {
         std::cerr << argv[0] << ": " << error.what() << std::endl;
-        return -1;
+        return 0;
     }
     return 0;
 }
-
