@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-2017 The Squid Software Foundation and contributors
+ * Copyright (C) 1996-2014 The Squid Software Foundation and contributors
  *
  * Squid software is distributed under GPLv2+ license and includes
  * contributions from numerous individuals and organizations.
@@ -18,7 +18,14 @@
 #include <unistd.h>
 #endif
 
+#if 0
+#define assert(X) {if (!(X)) exit (1);}
 #include "splay.h"
+#undef assert
+#else
+#include "splay.h"
+#endif
+
 #include "util.h"
 
 class intnode
@@ -139,10 +146,7 @@ main(int argc, char *argv[])
         for (i = 0; i < 100; ++i) {
             I = (intnode *)xcalloc(sizeof(intnode), 1);
             I->i = squid_random();
-            if (top)
-                top = top->insert(I, compareintvoid);
-            else
-                top = new splayNode(static_cast<void*>(new intnode(101)));
+            top = top->insert(I, compareintvoid);
         }
 
         SplayCheck::BeginWalk();
@@ -151,12 +155,15 @@ main(int argc, char *argv[])
         SplayCheck::BeginWalk();
         top->walk(SplayCheck::WalkVoid, NULL);
         top->destroy(destintvoid);
+        /* check we don't segfault on NULL splay calls */
+        top = NULL;
+        top->splay((void *)NULL, compareintvoid);
     }
 
     /* test typesafe splay containers */
     {
         /* intnode* */
-        SplayNode<intnode *> *safeTop = new SplayNode<intnode *>(new intnode(101));
+        SplayNode<intnode *> *safeTop = NULL;
 
         for ( int i = 0; i < 100; ++i) {
             intnode *I;
@@ -169,10 +176,13 @@ main(int argc, char *argv[])
         safeTop->walk(SplayCheck::WalkNode, NULL);
 
         safeTop->destroy(destint);
+        /* check we don't segfault on NULL splay calls */
+        safeTop = NULL;
+        safeTop->splay((intnode *)NULL, compareint);
     }
     {
         /* intnode */
-        SplayNode<intnode> *safeTop = new SplayNode<intnode>(101);
+        SplayNode<intnode> *safeTop = NULL;
 
         for (int i = 0; i < 100; ++i) {
             intnode I;
@@ -184,6 +194,11 @@ main(int argc, char *argv[])
         safeTop->walk(SplayCheck::WalkNodeRef, NULL);
 
         safeTop->destroy(destintref);
+        /* check we don't segfault on NULL splay calls */
+        safeTop = NULL;
+        safeTop->splay(intnode(), compareintref);
+        SplayCheck::BeginWalk();
+        safeTop->walk(SplayCheck::WalkNodeRef, NULL);
     }
 
     /* check the check routine */
@@ -200,7 +215,7 @@ main(int argc, char *argv[])
 
     {
         /* check for begin() */
-        Splay<intnode> *safeTop = new Splay<intnode>();
+        SplayNode<intnode> *safeTop = NULL;
 
         if (safeTop->start() != NULL)
             exit (1);
@@ -213,15 +228,15 @@ main(int argc, char *argv[])
             I.i = squid_random();
 
             if (I.i > 50 && I.i < 10000000)
-                safeTop->insert(I, compareintref);
+                safeTop = safeTop->insert(I, compareintref);
         }
 
         {
             intnode I;
             I.i = 50;
-            safeTop->insert (I, compareintref);
+            safeTop = safeTop->insert (I, compareintref);
             I.i = 10000000;
-            safeTop->insert (I, compareintref);
+            safeTop = safeTop->insert (I, compareintref);
         }
 
         if (!safeTop->start())
@@ -265,8 +280,5 @@ main(int argc, char *argv[])
             exit (1);
     }
 
-    /* TODO: also test the other Splay API */
-
     return 0;
 }
-
